@@ -37,7 +37,7 @@
 #include "interface.h"
 #include "support.h"
 #include "folder.h"
-#include "feed.h"
+#include "feedlist.h"
 #include "item.h"
 #include "conf.h"
 #include "export.h"
@@ -83,7 +83,7 @@ static void callbacks_schedule_update_default_cb(nodePtr ptr) {
 	feed_schedule_update((feedPtr)ptr, 0);
 }
 
-void ui_init(gboolean startIconified) {
+void ui_init(int mainwindowState) {
 	GtkWidget	*widget;
 	int		i;
 
@@ -138,12 +138,19 @@ void ui_init(gboolean startIconified) {
 #endif
 
 	/* setup one minute timer for automatic updating, and try updating now */
- 	(void)g_timeout_add(60*1000, ui_feedlist_auto_update, NULL);
-	ui_feedlist_auto_update(NULL);
+ 	(void)g_timeout_add(60*1000, feedlist_auto_update, NULL);
+	feedlist_auto_update(NULL);
 	
-	if(startIconified)
+	if (mainwindowState == MAINWINDOW_ICONIFIED || (mainwindowState == MAINWINDOW_HIDDEN && ui_tray_get_count() == 0)) {
 		gtk_window_iconify(GTK_WINDOW(mainwindow));
-	gtk_widget_show(mainwindow);
+		gtk_widget_show(mainwindow);
+	} else if (mainwindowState == MAINWINDOW_SHOWN)
+		gtk_widget_show(mainwindow);
+	else
+		/* Needed so that the window structure can be
+		   accessed... otherwise will GTK warning when window is
+		   shown by clicking on notification icon. */
+		gtk_widget_realize(GTK_WIDGET(mainwindow)); 
 	ui_mainwindow_finish(mainwindow); /* Ugly hack to make mozilla work */
 		
 }
@@ -230,3 +237,16 @@ void on_homepagebtn_clicked(GtkButton *button, gpointer user_data) {
 	ui_htmlview_launch_in_external_browser(_("http://liferea.sf.net"));
 }
 
+void on_topics_activate(GtkMenuItem *menuitem, gpointer user_data) {
+	gchar *filename = g_strdup_printf("file://" PACKAGE_DATA_DIR "/" PACKAGE "/doc/html/%s", _("topics_en.html"));
+	ui_tabs_new(filename, _("Help Topics"), TRUE);
+	g_free(filename);
+}
+
+
+void on_quick_reference_activate(GtkMenuItem *menuitem, gpointer user_data) {
+	gchar *filename = g_strdup_printf("file://" PACKAGE_DATA_DIR "/" PACKAGE "/doc/html/%s", _("reference_en.html"));
+	ui_tabs_new(filename, _("Quick Reference"), TRUE);
+	g_free(filename);
+}
+
