@@ -34,6 +34,7 @@
 #include "ui_htmlview.h"
 #include "ui_tabs.h"
 #include "itemlist.h"
+#include "feedlist.h"
 
 /* icon constants */
 enum icons {
@@ -58,7 +59,7 @@ extern GdkPixbuf *icons[MAX_ICONS];
  * GUI initialization methods. Sets up dynamically created
  * widgets, load persistent settings and starts cache loading.
  */
-void ui_init(gboolean startIconified);
+void ui_init(gint mainwindowState);
 
 #define ui_redraw_itemlist()	ui_redraw_widget("Itemlist");
 #define ui_redraw_feedlist()	ui_redraw_widget("feedlist");
@@ -96,34 +97,6 @@ void
 on_about_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-void
-on_menu_folder_new                     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_menu_feed_new                     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_menu_delete                         (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_menu_properties                     (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_menu_update                         (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_menu_folder_delete                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
-void
-on_menu_folder_rename                  (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-
 gboolean
 on_close                               (GtkWidget       *widget,
                                         GdkEvent        *event,
@@ -139,3 +112,11 @@ on_homepagebtn_clicked                 (GtkButton       *button,
                                         gpointer         user_data);
 
 #endif
+
+void
+on_topics_activate                     (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_quick_reference_activate            (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
