@@ -235,6 +235,50 @@ gchar * unhtmlize(gchar *string) {
  	}
 }
 
+/* Converts a UTF-8 strings containing any XML stuff to 
+   a string without any entities or tags containing all
+   text nodes of the given HTML string. The original 
+   string will be freed. */
+gchar * unxmlize(gchar *string) {
+	xmlSAXHandler	*sax_p = NULL;
+	xmlParserCtxtPtr	ctxt;
+	gchar			*result;
+	result_buffer		*buffer;
+	
+	if(NULL == string)
+		return NULL;
+		
+	string = utf8_fix(string);
+
+	/* only do something if there are any entities or tags */
+	if(NULL == (strpbrk(string, "&<>")))
+		return string;
+
+	buffer = g_new0(result_buffer, 1);
+	sax_p = g_new0(xmlSAXHandler, 1);
+ 	sax_p->characters = unhtmlizeHandleCharacters;
+
+	/* in older versions htmlSAXParseDoc was used which caused
+	   strange crashes when freeing the parser context... */
+	   
+	ctxt = xmlCreatePushParserCtxt(sax_p, buffer, string, strlen(string), "");
+	xmlParseChunk(ctxt, string, 0, 1);
+	xmlFreeParserCtxt(ctxt);
+	result = buffer->data;
+	g_free(buffer);
+ 	g_free(sax_p);
+ 
+ 	if(result == NULL || !g_utf8_strlen(result, -1)) {
+ 		/* Something went wrong in the parsing.
+ 		 * Use original string instead */
+		g_free(result);
+ 		return string;
+ 	} else {
+ 		g_free(string);
+ 		return result;
+ 	}
+}
+
 #define MAX_PARSE_ERROR_LINES	10
 
 /** used by bufferParseError to keep track of error messages */
@@ -477,9 +521,9 @@ static struct {
 	{ "Y", 1200 }
 };
 /** @returns timezone offset in seconds */
-static time_t common_parse_rfc822_tz(unsigned char *token) {
+static time_t common_parse_rfc822_tz(char *token) {
 	int offset = 0;
-	const unsigned char *inptr = token;
+	const char *inptr = token;
 	
 	if (*inptr == '+' || *inptr == '-') {
 		offset = atoi (inptr);
@@ -677,13 +721,13 @@ gchar * encode_uri_string(gchar *string) {
 
 xmlChar * common_uri_escape(const xmlChar *url) {
 	xmlChar	*result;
-	
+
 	result = xmlURIEscape(url);
 	
 	/* workaround for libxml2 problem... */
 	if(NULL == result)
 		result = g_strdup(url);
-		
+
 	return result;	
 }
 
@@ -702,7 +746,7 @@ xmlChar * common_build_url(const gchar *url, const gchar *baseURL) {
 	} else {
 		absURL = escapedURL;
 	}
-	
+
 	return absURL;
 }
 
