@@ -36,7 +36,7 @@ struct folder;
 
 typedef struct node {
 	gint type;
-	gpointer *ui_data;
+	gpointer ui_data;
 } *nodePtr;
 
 /** Conversion function which should be applied to all read XML strings, 
@@ -51,6 +51,7 @@ gchar * convertToHTML(gchar * string);
 /* converts a UTF-8 string containing HTML tags to plain text */
 gchar * unhtmlize(gchar *string);
 
+gchar * unxmlize(gchar *string);
 /* parses a XML node and returns its contents as a string */
 /* gchar * parseHTML(htmlNodePtr cur); */
 
