@@ -49,7 +49,7 @@
 static GConfClient	*client;
 
 static guint feedlist_save_timer;
-gboolean feedlistLoading = FALSE;	/* flag set during initial feed list loading */
+static gboolean feedlistLoading = FALSE;	/* flag set during initial feed list loading */
 
 /* configuration strings for the SnowNews HTTP code used from within netio.c */
 char 	*useragent = NULL;
@@ -63,22 +63,10 @@ static void conf_proxy_reset_settings_cb(GConfClient *client, guint cnxn_id, GCo
 static void conf_tray_settings_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data);
 static void conf_toolbar_style_settings_cb(GConfClient *client, guint cnxn_id, GConfEntry *entry, gpointer user_data);
 
-static gchar * build_path_str(gchar *str1, gchar *str2) {
-	gchar	*gconfpath;
-
-	g_assert(NULL != str1);
-	if(0 == strcmp(str1, "")) 
-		gconfpath = g_strdup_printf("%s/%s", PATH, str2);
-	else
-		gconfpath = g_strdup_printf("%s/%s/%s", PATH, str1, str2);
-		
-	return gconfpath;
-}
-
 static gboolean is_gconf_error(GError **err) {
 
 	if(*err != NULL) {
-		g_print("%s\n", (*err)->message);
+		g_warning("%s\n", (*err)->message);
 		g_error_free(*err);
 		*err = NULL;
 		return TRUE;
@@ -89,7 +77,6 @@ static gboolean is_gconf_error(GError **err) {
 
 /* called once on startup */
 void conf_init() {
-	const char	*lang;
 	
 	/* has to be called for multithreaded programs */
 	xmlInitParser();
