@@ -39,10 +39,6 @@
 #include "ui_feedlist.h"
 #include "debug.h"
 
-/* _() for HELP1URL to allow localised help feeds */
-#define HELP1URL_1 	_("http://liferea.sf.net/help/help")
-#define HELP1URL_2	_(".rdf")
-
 struct exportData {
 	gboolean internal; /**< Include all the extra Liferea-specific tags */
 	xmlNodePtr cur;
@@ -289,15 +285,6 @@ static void import_parse_outline(xmlNodePtr cur, folderPtr folder, gboolean trus
 		source = xmlGetProp(cur, BAD_CAST"xmlurl");	/* e.g. for AmphetaDesk */
 	
 	if(NULL != source) { /* Reading a feed */
-		/* check if source is a help feed... */
-		if(0 == strncmp(source, HELP1URL_1, strlen(HELP1URL_1))) {
-			/* If it is we rebuild it with the current version 
-			   just to be sure it is up-to-date. Of course this 
-			   means there must be no other feeds under the
-			   URL given by HELP1URL!!! */
-			xmlFree(source);
-			source = g_strdup_printf("%s%s%s", HELP1URL_1, VERSION, HELP1URL_2);
-		}
 	
 		filter = xmlGetProp(cur, BAD_CAST"filtercmd");
 
@@ -417,7 +404,7 @@ static void import_parse_outline(xmlNodePtr cur, folderPtr folder, gboolean trus
 				                         | FEED_REQ_AUTH_DIALOG);
 		}
 
-		ui_feedlist_add(folder, (nodePtr)fp, -1);
+		feedlist_add_feed(folder, (feedPtr)fp, -1);
 		
 		if(source != NULL)
 			xmlFree(source);
@@ -429,7 +416,7 @@ static void import_parse_outline(xmlNodePtr cur, folderPtr folder, gboolean trus
 		debug1(DEBUG_CONF, "adding folder \"%s\"", title);
 		child = restore_folder(folder, title, NULL, FST_FOLDER);
 		g_assert(NULL != child);
-		ui_feedlist_add(folder, (nodePtr)child, -1);
+		feedlist_add_folder(folder, (folderPtr)child, -1);
 		folder = child;
 
 		if(NULL != xmlHasProp(cur, BAD_CAST"expanded"))
@@ -486,9 +473,9 @@ static void import_parse_OPML(xmlNodePtr n, folderPtr parent, gboolean trusted)
  */
 static void import_initial_load_feed(feedPtr fp) {
 
-	if(!feed_load(fp))
+	if(!feedlist_load_feed(fp))
 		feed_schedule_update(fp, 0);
-	feed_unload(fp);
+	feedlist_unload_feed(fp);
 }
 
 void import_OPML_feedlist(const gchar *filename, folderPtr parent, gboolean showErrors, gboolean trusted) {
@@ -543,7 +530,7 @@ void on_import_activate_cb(const gchar *filename, gpointer user_data) {
 		folder = restore_folder(NULL, _("Imported feed list"), NULL, FST_FOLDER);
 		
 		/* add the new folder to the model */
-		ui_feedlist_add(NULL, (nodePtr)folder, -1);
+		feedlist_add_folder(NULL, (folderPtr)folder, -1);
 		
 		import_OPML_feedlist(filename, folder, TRUE, FALSE);
 	}
