@@ -1,7 +1,7 @@
 /**
  * @file feed.c common feed handling
  * 
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2003-2005 Lars Lindner <lars.lindner@gmx.net>
  * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -39,6 +39,7 @@
 #include "html.h"
 #include "cdf_channel.h"
 #include "rss_channel.h"
+#include "atom10.h"
 #include "pie_feed.h"
 #include "ocs_dir.h"
 #include "opml.h"
@@ -57,8 +58,6 @@
 #include "ui_tray.h"
 #include "ui_htmlview.h"
 
-extern gboolean feedlistLoading;	/* flag in conf.c that is set upon initial feed list loading */
-
 /* auto detection lookup table */
 static GSList *feedhandlers;
 
@@ -73,6 +72,7 @@ void feed_init(void) {
 	feedhandlers = g_slist_append(feedhandlers, ocs_init_feed_handler()); /* Must come before RSS/RDF */
 	feedhandlers = g_slist_append(feedhandlers, rss_init_feed_handler());
 	feedhandlers = g_slist_append(feedhandlers, cdf_init_feed_handler());
+	feedhandlers = g_slist_append(feedhandlers, atom10_init_feed_handler());  /* Must be before pie */
 	feedhandlers = g_slist_append(feedhandlers, pie_init_feed_handler());
 	feedhandlers = g_slist_append(feedhandlers, opml_init_feed_handler());
 	feedhandlers = g_slist_append(feedhandlers, vfolder_init_feed_handler());
@@ -157,7 +157,7 @@ feedHandlerPtr feed_parse(feedPtr fp, gchar *data, size_t dataLength, gboolean a
 			addToHTMLBuffer(&(fp->parseErrors), _("<p>Empty document!</p>"));
 			break;
 		}
-		while(cur && xmlIsBlankNode(cur)) {
+		while(cur != NULL && xmlIsBlankNode(cur)) {
 			cur = cur->next;
 		}
 		if(NULL == cur->name) {
@@ -183,7 +183,7 @@ feedHandlerPtr feed_parse(feedPtr fp, gchar *data, size_t dataLength, gboolean a
 				fp->metadata = NULL;
 				
 				if(FALSE == handler->merge)
-					feed_clear_item_list(fp);	/* for directories */
+					feed_remove_items(fp);	/* for directories */
 				
 				(*(handler->feedParser))(fp, doc, cur);		/* parse it */
 				handled = TRUE;				
@@ -224,12 +224,13 @@ feedHandlerPtr feed_parse(feedPtr fp, gchar *data, size_t dataLength, gboolean a
 				download_request_free(request);
 			} else {
 				debug0(DEBUG_UPDATE, "no feed link found!");
+				feed_set_available(fp, FALSE);
+				addToHTMLBuffer(&(fp->parseErrors), _("<p>The URL you want Liferea to subscribe to points to a webpage and the auto discovery found no feeds on this page. Maybe this webpage just does not support feed auto discovery.</p>"));
 			}
 		} else {
+			debug0(DEBUG_UPDATE, "neither a known feed type nor a HTML document!");
 			feed_set_available(fp, FALSE);
-			debug0(DEBUG_UPDATE, "There were errors while parsing a feed!");
-			ui_mainwindow_set_status_bar(_("There were errors while parsing a feed"));
-			addToHTMLBuffer(&(fp->parseErrors), _("<p>Could not determine the feed type. Please check that it is <a href=\"http://feedvalidator.org\">valid</a> and in a <a href=\"http://liferea.sourceforge.net/index.php#supported_formats\">supported format</a>.</p>"));
+			addToHTMLBuffer(&(fp->parseErrors), _("<p>Could not determine the feed type. Please check that it is <a href=\"http://feedvalidator.org\">valid</a> and in a <a href=\"http://liferea.sourceforge.net/supported_formats.htm\">supported format</a>.</p>"));
 		}
 	} else {
 		debug1(DEBUG_UPDATE, "discovered feed format: %s", feed_type_fhp_to_str(handler));
@@ -255,7 +256,7 @@ void feed_save(feedPtr fp) {
 	xmlDocPtr 	doc;
 	xmlNodePtr 	feedNode;
 	GSList		*itemlist, *iter;
-	gchar		*filename;
+	gchar		*filename, *tmpfilename;
 	gchar		*tmp;
 	itemPtr		ip;
 	gint		saveCount = 0;
@@ -276,6 +277,7 @@ void feed_save(feedPtr fp) {
 		saveMaxCount = getNumericConfValue(DEFAULT_MAX_ITEMS);
 	
 	filename = common_create_cache_filename("cache" G_DIR_SEPARATOR_S "feeds", fp->id, NULL);
+	tmpfilename = g_strdup_printf("%s~", filename);
 	
 	if(NULL != (doc = xmlNewDoc("1.0"))) {	
 		if(NULL != (feedNode = xmlNewDocNode(doc, NULL, "feed", NULL))) {
@@ -316,7 +318,7 @@ void feed_save(feedPtr fp) {
 				if((saveMaxCount != CACHE_UNLIMITED) &&
 				   (saveCount >= saveMaxCount) &&
 				   (fp->fhp == NULL || fp->fhp->directory == FALSE) &&
-				   !item_get_flag(ip)) {
+				   ! item_get_flag_status(ip)) {
 				   	itemlist_remove_item(ip);
 				} else {
 					item_save(ip, feedNode);
@@ -327,20 +329,28 @@ void feed_save(feedPtr fp) {
 		} else {
 			g_warning("could not create XML feed node for feed cache document!");
 		}
-		xmlSaveFormatFileEnc(filename, doc, NULL, 1);
+		if (xmlSaveFormatFile(tmpfilename, doc,1) == -1) {
+			g_warning("Error attempting to save feed cache file \"%s\"!", tmpfilename);
+		} else {
+			if (rename(tmpfilename, filename) == -1)
+				perror("Error overwriting old cache file"); /* Nothing else can be done... probably the disk is going bad */
+		}
 		xmlFreeDoc(doc);
-		g_free(filename);
 	} else {
 		g_warning("could not create XML document!");
 	}
 	
+	g_free(tmpfilename);
+	g_free(filename);
+
 	fp->needsCacheSave = FALSE;
 	debug_exit("feed_save");
 }
 
 /* Function which is called to load a feed's into memory. This function
    might be called multiple times even if the feed was already loaded.
-   Each time the method is called a reference counter is incremented. */
+   Each time the method is called a reference counter is incremented. 
+   Only to be called by feedlist_load_feed(). */
 gboolean feed_load(feedPtr fp) {
 	xmlDocPtr 	doc;
 	xmlNodePtr 	cur;
@@ -348,22 +358,12 @@ gboolean feed_load(feedPtr fp) {
 	gchar		*filename, *tmp, *data = NULL;
 	int		error = 0;
 	gsize 		length;
-	
+
 	debug_enter("feed_load");
 	debug1(DEBUG_CACHE, "feed_load for %s\n", feed_get_source(fp));
-	g_assert(NULL != fp);	
+	g_assert(NULL != fp);
 	g_assert(NULL != fp->id);
 	
-	if(FST_VFOLDER == feed_get_type(fp)) {
-		debug0(DEBUG_CACHE, "it's a vfolder, nothing to do...");
-		return TRUE;
-	}
-	
-	if(0 != (fp->loaded)++) {
-		debug0(DEBUG_CACHE, "feed already loaded!\n");
-		return TRUE;
-	}
-
 	filename = common_create_cache_filename("cache" G_DIR_SEPARATOR_S "feeds", fp->id, NULL);
 	debug1(DEBUG_CACHE, "loading cache file \"%s\"", filename);
 		
@@ -404,9 +404,10 @@ gboolean feed_load(feedPtr fp) {
 			break;		
 		}
 
-		fp->unreadCount = 0;
 		metadata_list_free(fp->metadata);
 		fp->metadata = NULL;
+		fp->unreadCount = 0;
+		fp->newCount = 0;
 
 		cur = cur->xmlChildrenNode;
 		while(cur != NULL) {
@@ -472,40 +473,28 @@ gboolean feed_load(feedPtr fp) {
    
    Each time this function is called the reference counter of all
    feeds is decremented and if it zero the unnecessary feed infos are 
-   free'd */
+   free'd. Only to be called by feedlist_unload_feed(). */
 void feed_unload(feedPtr fp) {
-	gint 	unreadCount;
 
 	g_assert(NULL != fp);
-	g_assert(0 <= fp->loaded);	/* could indicate bad loaded reference counting */
-		
-	if(FST_VFOLDER == feed_get_type(fp)) {
-		debug0(DEBUG_CACHE, "it's a vfolder, nothing to do...");
-		return;
-	}
+	g_assert(0 != fp->loaded);
 	
-	if(0 != fp->loaded) {
-		feed_save(fp);		/* save feed before unloading */
+	feed_save(fp);		/* save feed before unloading */
 
-		if(!getBooleanConfValue(KEEP_FEEDS_IN_MEMORY)) {
-			debug_enter("feed_unload");
-			if(1 == fp->loaded) {
-				if(FST_FEED == feed_get_type(fp)) {
-					debug1(DEBUG_CACHE, "feed_unload (%s)", feed_get_source(fp));
-
-					/* free items */
-					unreadCount = fp->unreadCount;
-					feed_clear_item_list(fp);						
-					fp->unreadCount = unreadCount;
-				} else {
-					debug1(DEBUG_CACHE, "not unloading vfolder (%s)",  feed_get_title(fp));
-				}
+	if(!getBooleanConfValue(KEEP_FEEDS_IN_MEMORY)) {
+		debug_enter("feed_unload");
+		if(1 == fp->loaded) {
+			if(FST_FEED == feed_get_type(fp)) {
+				debug1(DEBUG_CACHE, "feed_unload (%s)", feed_get_source(fp));
+				feed_clear_item_list(fp);						
 			} else {
-				debug2(DEBUG_CACHE, "not unloading (%s) because it's used (%d references)...", feed_get_source(fp), fp->loaded);
+				debug1(DEBUG_CACHE, "not unloading vfolder (%s)",  feed_get_title(fp));
 			}
-			fp->loaded--;
-			debug_exit("feed_unload");
+		} else {
+			debug2(DEBUG_CACHE, "not unloading (%s) because it's used (%d references)...", feed_get_source(fp), fp->loaded);
 		}
+		fp->loaded--;
+		debug_exit("feed_unload");
 	}
 }
 
@@ -671,17 +660,21 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 		
 			if(FALSE == item_get_read_status(new_ip))
 				feed_increase_unread_counter(fp);
-			if(TRUE == new_ip->newStatus) {
-				fp->newCount++;
-				ui_tray_add_new(1);
-			}
+				
+			if(TRUE == item_get_popup_status(new_ip))
+				feed_increase_popup_counter(fp);
+				
+			if(TRUE == item_get_new_status(new_ip))
+				feed_increase_new_counter(fp);
+				
+			feedlist_update_counters(item_get_read_status(new_ip)?0:1,
+						 item_get_new_status(new_ip)?1:0);
+
 			fp->items = g_slist_prepend(fp->items, (gpointer)new_ip);
 			new_ip->fp = fp;
 	
-			if((TRUE == new_ip->newStatus) || (feedlistLoading)) {
-				/* check if the item matches any vfolder rules */
-				vfolder_check_item(new_ip);
-			}
+			/* check if the item matches any vfolder rules */
+			vfolder_check_item(new_ip);
 			
 			debug0(DEBUG_VERBOSE, "-> item added to feed itemlist");
 			
@@ -702,7 +695,7 @@ void feed_add_item(feedPtr fp, itemPtr new_ip) {
 			}
 		}
 	} else {
-		/* just add the item */
+		/* in case of vfolder just add the item */
 		if(FALSE == item_get_read_status(new_ip))
 			feed_increase_unread_counter(fp);
 		fp->items = g_slist_append(fp->items, (gpointer)new_ip);
@@ -760,6 +753,14 @@ void feed_decrease_unread_counter(feedPtr fp) {
 }
 gint feed_get_unread_counter(feedPtr fp) { return fp->unreadCount; }
 
+void feed_increase_popup_counter(feedPtr fp) {
+	fp->popupCount++;
+}
+void feed_decrease_popup_counter(feedPtr fp) {
+	fp->popupCount--;
+}
+gint feed_get_popup_counter(feedPtr fp) { return fp->popupCount; }
+
 void feed_increase_new_counter(feedPtr fp) {
 	fp->newCount++;
 }
@@ -788,7 +789,7 @@ void feed_set_update_interval(feedPtr fp, gint interval) {
 	conf_feedlist_schedule_save();
 }
 
-const feedHandlerPtr feed_get_fhp(feedPtr fp) {
+feedHandlerPtr feed_get_fhp(feedPtr fp) {
 	return fp->fhp;
 }
 
@@ -822,7 +823,7 @@ gchar * feed_get_error_description(feedPtr fp) {
 	return tmp1; 
 }
 
-const time_t feed_get_time(feedPtr fp) { return (fp != NULL ? fp->time : 0); }
+time_t feed_get_time(feedPtr fp) { return (fp != NULL ? fp->time : 0); }
 void feed_set_time(feedPtr fp, const time_t t) { fp->time = t; }
 
 const gchar * feed_get_title(feedPtr fp) { 
@@ -859,7 +860,7 @@ const gchar * feed_get_filter(feedPtr fp) { return fp->filtercmd; }
 void feed_set_source(feedPtr fp, const gchar *source) {
 	g_free(fp->source);
 
-	fp->source = g_strdup(source);
+	fp->source = g_strchomp(g_strdup(source));
 	conf_feedlist_schedule_save();
 	
 	g_free(fp->cookies);
@@ -882,7 +883,7 @@ void feed_set_html_url(feedPtr fp, const gchar *htmlUrl) {
 
 	g_free(fp->htmlUrl);
 	if(htmlUrl != NULL)
-		fp->htmlUrl = g_strdup(htmlUrl);
+		fp->htmlUrl = g_strchomp(g_strdup(htmlUrl));
 	else
 		fp->htmlUrl = NULL;
 }
@@ -912,7 +913,7 @@ void feed_set_image_url(feedPtr fp, const gchar *imageUrl) {
 
 	g_free(fp->imageUrl);
 	if(imageUrl != NULL)
-		fp->imageUrl = g_strdup(imageUrl);
+		fp->imageUrl = g_strchomp(g_strdup(imageUrl));
 	else
 		fp->imageUrl = NULL;
 }
@@ -947,6 +948,7 @@ void feed_clear_item_list(feedPtr fp) {
 	while(NULL != item) {
 		item_free(item->data);
 		item = g_slist_next(item);
+		/* explicitly not changing the item state counters */
 	}
 	g_slist_free(fp->items);
 	fp->items = NULL;
@@ -959,20 +961,30 @@ void feed_clear_item_list(feedPtr fp) {
  */
 void feed_remove_item(feedPtr fp, itemPtr ip) {
 
-	if(NULL == fp)
-		return;
+	g_assert(NULL != fp);
 		
-	/*g_print("removing item %d from feed %d\n", ip, fp);
-	g_print("   feed:%s\n", fp->title);
-	g_print("   item:%s\n", ip->title);*/
-	if(NULL != g_slist_find(fp->items, ip)) {
+	if(NULL != g_slist_find(fp->items, ip)) {	
 		fp->items = g_slist_remove(fp->items, ip);	
-		if(FST_FEED == fp->type) {
+		
+		if(FST_VFOLDER != fp->type) {
 			vfolder_remove_item(ip);		/* remove item copies */
 			fp->needsCacheSave = TRUE;
+			
+			feedlist_update_counters(item_get_read_status(ip)?0:-1,
+						 item_get_new_status(ip)?-1:0);
 		}
-		/*g_print("freeing item structure %d\n", ip);*/
-		item_free(ip);					/* remove the item */
+ 
+		if(FALSE == item_get_read_status(ip))
+			feed_decrease_unread_counter(fp);
+		
+		if(TRUE == item_get_popup_status(ip))
+			feed_decrease_popup_counter(fp);
+		
+		if(TRUE == item_get_new_status(ip))
+			feed_decrease_new_counter(fp);
+		
+		item_free(ip);
+
 	} else {
 		g_warning("feed_remove_item(): item (%s) to be removed not found...", ip->title);
 	}
@@ -992,6 +1004,10 @@ void feed_remove_items(feedPtr fp) {
 		item = g_slist_next(item);
 	}
 	g_slist_free(fp->items);
+	feedlist_update_counters((-1)*fp->unreadCount, (-1)*fp->newCount);
+	fp->unreadCount = 0;
+	fp->popupCount = 0;
+	fp->newCount = 0;
 	fp->items = NULL;
 	fp->needsCacheSave = TRUE;	/* force feed saving to make it permanent */
 }
