@@ -22,7 +22,10 @@
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
+#define _GNU_SOURCE
 
+
+#include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
 #include "support.h"
@@ -30,82 +33,64 @@
 #include "debug.h"
 #include "html.h"
 
-static gchar *checkLinkRef(const gchar* str) {
+enum {
+	LINK_FAVICON,
+	LINK_RSS_ALTERNATE,
+	LINK_NORMAL_ANCHOR
+};
+
+static gchar *checkLinkRef(const gchar* str, gint linkType) {
 	gchar	*res;
-	gchar	*tmp, *tmp2;
-
-	/*debug1(DEBUG_PARSING, "checking link %s", str); */
-	tmp = strstr(str, "href=");
-	if(NULL == tmp) tmp = strstr(str, "HREF=");
-	if(NULL == tmp) return NULL;
-	/* FIXME: single quotes support */
-	tmp2 = strchr(tmp, '\"');
-	if(NULL == tmp2) return NULL;
-	tmp = strchr(tmp2+1, '\"');
-	*tmp = '\0';
-	res = g_strdup(tmp2+1);
-	*tmp = '\"';
-
-	if((strstr(str, "alternate")!=NULL) &&
-	   ((strstr(str, "text/xml")!=NULL) || 
-	    (strstr(str, "rss+xml")!=NULL) ||
-	    (strstr(str, "rdf+xml")!=NULL) ||
-	    (strstr(str, "atom+xml")!=NULL)))
-		return res;
-	g_free(res);
-	return NULL;
-}
-
-static gchar *checkLinkRefForFavicon(const gchar* str) {
-	gchar	*res;
-	gchar	*tmp, *tmp2;
-
-	/*debug1(DEBUG_PARSING, "checking link %s", str); */
-	tmp = strstr(str, "href=");
-	if(NULL == tmp) tmp = strstr(str, "HREF=");
-	if(NULL == tmp) return NULL;
-	/* FIXME: single quotes support */
-	tmp2 = strchr(tmp, '\"');
+	const gchar	*tmp, *tmp2;
+	size_t	len=0;
+	gchar	quote; 
 	
-	if(NULL == tmp2) return NULL;
-	tmp = strchr(tmp2+1, '\"');
-	if (tmp == NULL) return NULL;
-	*tmp = '\0';
-	res = g_strdup(tmp2+1);
-	*tmp = '\"';
-
-	if((strstr(str, "shortcut icon")!=NULL ||
-		strstr(str, "icon")!=NULL) &&
-	   ((strstr(str, "image/x-icon")!=NULL)))
-		return res;
-	g_free(res);
-	return NULL;
-}
-
-static gchar *checkNormalLink(const gchar* str) {
-	gchar	*res, *tmp, *tmp2;
-
-	debug1(DEBUG_PARSING, "checking link %s", str);
-	tmp = strstr(str, "href=");
-	if(NULL == tmp) tmp = strstr(str, "HREF=");
+	/*debug1(DEBUG_PARSING, "checking link %s", str); */
+	tmp = strcasestr(str, "href=");
 	if(NULL == tmp) return NULL;
-	/* FIXME: single quotes support */
-	tmp2 = strchr(tmp, '\"');
-	if(NULL == tmp2) return NULL;
-	tmp = strchr(tmp2+1, '\"');
-	if (tmp == NULL) return NULL;
-	*tmp = '\0';
-	res = g_strdup(tmp2+1);
-	*tmp = '\"';
+	tmp += 5;
+	/* skip spaces up to the first quote. This is really slightly
+	 wrong.  SGML allows unquoted atributes, but not if they contain
+	 slashes, so 99% of all URIs will require quotes. */
+	while (*tmp != '\"' &&
+		  *tmp != '\'') {
+		if (*tmp == '>' ||
+		    *tmp == '\0' ||
+		    !isspace(*tmp))
+			return NULL;
+		tmp++;
+	}
+	quote = *tmp; /* The type of quote mark used to delimit the arg */
+	tmp++;
+	tmp2 = tmp;
+	while ((*tmp2 != quote && *(tmp2-1) != '\\') &&/* Escaped quote*/
+		  *tmp2 != '\0')
+		tmp2++, len++;
 
-	if((strstr(res, "rdf")) || (strstr(res, "xml")) ||
-	   (strstr(res, "rss")))
-		return res;
+	res = g_strndup(tmp, len);
+
+	if (linkType == LINK_FAVICON) {
+		if((strcasestr(str, "shortcut icon")!=NULL ||
+		    strcasestr(str, "icon")!=NULL) &&
+		   ((strcasestr(str, "image/x-icon")!=NULL)))
+			return res;
+	} else if (linkType == LINK_RSS_ALTERNATE){
+		if((strcasestr(str, "alternate")!=NULL) &&
+		   ((strcasestr(str, "text/xml")!=NULL) || 
+		    (strcasestr(str, "rss+xml")!=NULL) ||
+		    (strcasestr(str, "rdf+xml")!=NULL) ||
+		    (strcasestr(str, "atom+xml")!=NULL)))
+			return res;
+	} else if (linkType == LINK_NORMAL_ANCHOR){
+		if((strstr(res, "rdf")) || (strstr(res, "xml")) ||
+		   (strstr(res, "rss")))
+			return res;
+	}
 	g_free(res);
 	return NULL;
 }
 
-static gchar *search_links(const gchar* data, int type, gboolean favicon) {
+static gchar *search_links(const gchar* data, gint linkType) {
 	gchar	*ptr;
 	const gchar	*tmp = data;
 	gchar	*result = NULL;
@@ -114,9 +99,7 @@ static gchar *search_links(const gchar* data, int type, gboolean favicon) {
 	gchar	*endptr;
 	
 	while(1) {
-		ptr = strstr(tmp, ((type == 0)? "<link " : "<a "));
-		if(NULL == ptr)
-			ptr = strstr(tmp, ((type == 0)? "<LINK " : "<A "));
+		ptr = strcasestr(tmp, ((linkType != LINK_NORMAL_ANCHOR)? "<link " : "<a "));
 		if(NULL == ptr)
 			break;
 		
@@ -124,9 +107,7 @@ static gchar *search_links(const gchar* data, int type, gboolean favicon) {
 		*endptr = '\0';
 		tstr = g_strdup(ptr);
 		*endptr = '>';
-		res = ((type==0)?
-			  (favicon ? checkLinkRefForFavicon(tstr) : checkLinkRef(tstr))
-			  : checkNormalLink(tstr));
+		res = checkLinkRef(tstr, linkType);
 		g_free(tstr);
 		if(res != NULL){
 			result = res;
@@ -154,11 +135,11 @@ gchar * html_auto_discover_feed(const gchar* data, const gchar *baseUri) {
 	gchar	*res, *tmp;
 
 	debug0(DEBUG_UPDATE, "searching through link tags");
-	res = search_links(data, 0, FALSE);
+	res = search_links(data, LINK_RSS_ALTERNATE);
 	debug1(DEBUG_UPDATE, "search result: %s", res? res : "none found");
 	if(res == NULL) {
 		debug0(DEBUG_UPDATE, "searching through href tags");
-		res = search_links(data, 1, FALSE);
+		res = search_links(data, LINK_NORMAL_ANCHOR);
 		debug1(DEBUG_UPDATE, "search result: %s", res? res : "none found");
 	}
 
@@ -178,7 +159,7 @@ gchar * html_discover_favicon(const gchar* data, const gchar *baseUri) {
 	gchar	*res, *tmp;
 
 	debug0(DEBUG_UPDATE, "searching through link tags");
-	res = search_links(data, 0, TRUE);
+	res = search_links(data, LINK_FAVICON);
 	debug1(DEBUG_UPDATE, "search result: %s", res? res : "none found");
 
 	if (res != NULL) {
