@@ -26,9 +26,15 @@
 #include "conf.h"
 #include "debug.h"
 #include "feed.h"
+#include "feedlist.h"
 #include "support.h"
+#include "vfolder.h"
 #include "ui_itemlist.h"
 #include "ui_feedlist.h"
+#include "ui_feed.h"
+#include "ui_tray.h"
+#include "ui_htmlview.h"
+#include "ui_mainwindow.h"
 
 /* controller implementation for itemlist handling, bypass only for read-only feed/item access! */
 
@@ -46,7 +52,7 @@ static void itemlist_load_feed(feedPtr fp, gpointer data) {
 	itemPtr		ip;
 	
 	/* load model */
-	feed_load(fp);
+	feedlist_load_feed(fp);
 	/* update itemlist in view */	
 	itemlist = feed_get_item_list(fp);
 	itemlist = g_slist_copy(itemlist);
@@ -83,7 +89,7 @@ void itemlist_reload(nodePtr node) {
 	isFeed = (FST_FEED == displayed_node->type) || (FST_VFOLDER == displayed_node->type);
 	isFolder = FST_FOLDER == displayed_node->type;
 	g_assert(isFeed || isFolder);
-
+	
 	if((TRUE == isFolder) && (1 == getNumericConfValue(FOLDER_DISPLAY_MODE))) {
 		if((FST_FOLDER != node->type) && (node != displayed_node)) {
 			/* There are two cases: the updated feed is a child of
@@ -114,7 +120,6 @@ void itemlist_reload(nodePtr node) {
  */
 void itemlist_load(nodePtr node) {
 	GtkTreeModel	*model;
-	gint		sortColumn;
 	gboolean	isFeed;
 	gboolean	isFolder;
 
@@ -125,13 +130,16 @@ void itemlist_load(nodePtr node) {
 	if(isFeed && (node != displayed_node) && (TRUE == feed_get_two_pane_mode((feedPtr)displayed_node)))
 		itemlist_mark_all_read(displayed_node);
 
-	/* preparation done, we can select it... */
-	displayed_node = node;
-
 	/* determine what node type is now selected */
 	isFeed = ((node != NULL) && ((FST_FEED == node->type) || (FST_VFOLDER == node->type)));
 	isFolder = ((node != NULL) && (FST_FOLDER == node->type));
 	
+	if(isFolder && (0 == getNumericConfValue(FOLDER_DISPLAY_MODE)))
+		return;
+	
+	/* preparation done, we can select it... */
+	displayed_node = node;
+
 	if(!isFeed && !isFolder) {
 		ui_itemlist_clear();
 		displayed_node = NULL;
@@ -139,11 +147,9 @@ void itemlist_load(nodePtr node) {
 		return;
 	}
 	
-	if(isFolder && (1 != getNumericConfValue(FOLDER_DISPLAY_MODE)))
-		return;
-
+	
 	model = GTK_TREE_MODEL(ui_itemlist_get_tree_store());
-		
+	
 	if(isFeed) {
 		disableSortingSaving++;
 		gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), ((feedPtr)node)->sortColumn, ((feedPtr)node)->sortReversed?GTK_SORT_DESCENDING:GTK_SORT_ASCENDING);
@@ -151,7 +157,7 @@ void itemlist_load(nodePtr node) {
 	}
 	
 	if(isFolder)
-		ui_itemlist_set_two_pane_mode(FALSE);
+		itemlist_set_two_pane_mode(FALSE);
 		
 	ui_itemlist_clear();
 	/* explicitly no ui_htmlview_clear() !!! */
@@ -159,7 +165,7 @@ void itemlist_load(nodePtr node) {
 
 	if(!getBooleanConfValue(KEEP_FEEDS_IN_MEMORY)) {
 		debug0(DEBUG_CACHE, "unloading everything...");
-		ui_feedlist_do_for_all(NULL, ACTION_FILTER_FEED | ACTION_FILTER_DIRECTORY, feed_unload);
+		ui_feedlist_do_for_all(NULL, ACTION_FILTER_FEED | ACTION_FILTER_DIRECTORY, feedlist_unload_feed);
 	}
 	
 	itemlist_reload(node);
@@ -167,13 +173,13 @@ void itemlist_load(nodePtr node) {
 	ui_itemlist_prefocus();
 }
 
-void itemlist_update_vfolder(nodePtr vp) {
+void itemlist_update_vfolder(feedPtr vp) {
 
-	if(displayed_node == vp)
+	if(displayed_node == (nodePtr)vp)
 		/* maybe itemlist_load(vp) would be faster, but
 		   it unloads all feeds and therefore must not be 
 		   called from here! */		
-		itemlist_reload(vp);
+		itemlist_reload((nodePtr)vp);
 	else
 		ui_feed_update(vp);
 }
@@ -190,8 +196,8 @@ void itemlist_set_flag(itemPtr ip, gboolean newStatus) {
 	itemPtr		sourceItem;
 	feedPtr		sourceFeed;
 	
-	if(newStatus != item_get_flag(ip)) {
-		item_set_flag(ip, newStatus);
+	if(newStatus != item_get_flag_status(ip)) {
+		item_set_flag_status(ip, newStatus);
 		ui_itemlist_update_item(ip);
 
 		if(FST_FEED != ip->fp->type) {
@@ -199,22 +205,24 @@ void itemlist_set_flag(itemPtr ip, gboolean newStatus) {
 			if(ip->sourceFeed != NULL) {
 				/* propagate change to source feed, this indirectly updates us... */
 				sourceFeed = ip->sourceFeed;	/* keep feed pointer because ip might be free'd */
-				feed_load(sourceFeed);
+				feedlist_load_feed(sourceFeed);
 				if(NULL != (sourceItem = feed_lookup_item(sourceFeed, ip->sourceNr)))
 					itemlist_set_flag(sourceItem, newStatus);
-				feed_unload(sourceFeed);
+				feedlist_unload_feed(sourceFeed);
 			}
 		} else {
 			vfolder_update_item(ip);	/* there might be vfolders using this item */
 			vfolder_check_item(ip);		/* and check if now a rule matches */
 		}
 		ui_feedlist_update();
+
+		feedlist_reset_new_item_count();		
 	}
 }
 	
 void itemlist_toggle_flag(itemPtr ip) {
 
-	itemlist_set_flag(ip, !item_get_flag(ip));
+	itemlist_set_flag(ip, !item_get_flag_status(ip));
 }
 
 void itemlist_set_read_status(itemPtr ip, gboolean newStatus) {
@@ -230,19 +238,19 @@ void itemlist_set_read_status(itemPtr ip, gboolean newStatus) {
 			if(ip->sourceFeed != NULL) {
 				/* propagate change to source feed, this indirectly updates us... */
 				sourceFeed = ip->sourceFeed;	/* keep feed pointer because ip might be free'd */
-				feed_load(sourceFeed);
+				feedlist_load_feed(sourceFeed);
 				if(NULL != (sourceItem = feed_lookup_item(sourceFeed, ip->sourceNr)))
 					itemlist_set_read_status(sourceItem, newStatus);
-				feed_unload(sourceFeed);
+				feedlist_unload_feed(sourceFeed);
 			}
 		} else {		
 			vfolder_update_item(ip);	/* there might be vfolders using this item */
 			vfolder_check_item(ip);		/* and check if now a rule matches */
+			feedlist_update_counters(newStatus?-1:1, 0);
 		}
 		ui_feedlist_update();
-		
-		if(TRUE == newStatus)
-			ui_tray_zero_new();		/* reset tray icon */
+
+		feedlist_reset_new_item_count();
 	}
 }
 
@@ -264,16 +272,18 @@ void itemlist_set_update_status(itemPtr ip, const gboolean newStatus) {
 			if(ip->sourceFeed != NULL) {
 				/* propagate change to source feed, this indirectly updates us... */
 				sourceFeed = ip->sourceFeed;	/* keep feed pointer because ip might be free'd */
-				feed_load(sourceFeed);
+				feedlist_load_feed(sourceFeed);
 				if(NULL != (sourceItem = feed_lookup_item(sourceFeed, ip->sourceNr)))
 					itemlist_set_update_status(sourceItem, newStatus);
-				feed_unload(sourceFeed);
+				feedlist_unload_feed(sourceFeed);
 			}
 		} else {
 			vfolder_update_item(ip);	/* there might be vfolders using this item */
 			vfolder_check_item(ip);		/* and check if now a rule matches */
 		}
 		ui_feedlist_update();
+
+		feedlist_reset_new_item_count();
 	}
 }
 
@@ -286,7 +296,7 @@ void itemlist_mark_all_read(nodePtr np) {
 	} else {
 		/* if not we mark all items of the item list as read */
 		
-		feed_load((feedPtr)np);
+		feedlist_load_feed((feedPtr)np);
 
 		/* two loops on list copies because the itemlist_set_* 
 		   methods may modify the feeds original item list */
@@ -307,7 +317,7 @@ void itemlist_mark_all_read(nodePtr np) {
 		}
 		g_slist_free(items);
 
-		feed_unload((feedPtr)np);
+		feedlist_unload_feed((feedPtr)np);
 	}
 }
 
@@ -370,6 +380,8 @@ void on_itemlist_selection_changed(GtkTreeSelection *selection, gpointer data) {
 		} else {
 			displayed_item = NULL;
 		}
+
+		feedlist_reset_new_item_count();
 	}
 }
 
@@ -398,6 +410,6 @@ void itemlist_set_two_pane_mode(gboolean new_mode) {
 	if((NULL != (np = ui_feedlist_get_selected())) &&
 	   ((FST_FEED == np->type) || (FST_VFOLDER == np->type))) {
 		feed_set_two_pane_mode((feedPtr)np, new_mode);
-		ui_itemlist_set_two_pane_mode(new_mode);
 	}
+	ui_itemlist_set_two_pane_mode(new_mode);
 }
