@@ -58,7 +58,6 @@
 
 GThread	*mainThread = NULL;
 gboolean lifereaStarted = FALSE;
-gboolean	startIconified = FALSE;
 
 static void show_help(void) {
 	GString	*str = g_string_new(NULL);
@@ -67,7 +66,9 @@ static void show_help(void) {
 	g_string_append_printf(str, "Liferea %s\n\n", VERSION);
 	g_string_append_printf(str, "%s\n", _("  --version        Print version information and exit"));
 	g_string_append_printf(str, "%s\n", _("  --help           Print this help and exit"));
-	g_string_append_printf(str, "%s\n", _("  --iconify        Start the program iconified"));
+	g_string_append_printf(str, "%s\n", _("  --mainwindow-state=STATE"));
+	g_string_append_printf(str, "%s\n", _("                   Start Liferea with its main window in STATE."));
+	g_string_append_printf(str, "%s\n", _("                   STATE may be `shown', `iconified', or `hidden'"));
 	g_string_append_c(str, '\n');
 	g_string_append_printf(str, "%s\n", _("  --debug-cache    Print debugging messages for the cache handling"));
 	g_string_append_printf(str, "%s\n", _("  --debug-conf     Print debugging messages of the configuration handling"));
@@ -170,6 +171,7 @@ int main(int argc, char *argv[]) {
 	const char 	*arg;
 	gint		i;
 	GtkWidget	*dialog;
+	int mainwindowState = MAINWINDOW_SHOWN;
 #ifdef USE_SM
 	gchar *opt_session_arg = NULL;
 #endif
@@ -211,7 +213,17 @@ int main(int argc, char *argv[]) {
 			return 0;
 		}
 		else if(!strcmp(arg, "--iconify")) {
-			startIconified = TRUE;
+			mainwindowState = MAINWINDOW_ICONIFIED;
+		} else if(!strncmp(arg, "--mainwindow-state=",19)) {
+			const gchar *param = arg + 19;
+			if (g_str_equal(param, "iconified"))
+				mainwindowState = MAINWINDOW_ICONIFIED;
+			else if (g_str_equal(param, "hidden"))
+				mainwindowState = MAINWINDOW_HIDDEN;
+			else if (g_str_equal(param, "shown"))
+				mainwindowState = MAINWINDOW_SHOWN;
+			else
+				fprintf(stderr, _("The --mainwindow-state argument must be given a parameter.\n"));
 #ifdef USE_SM
 		}
 		else if (!strcmp(arg, "--session")) {
@@ -232,7 +244,7 @@ int main(int argc, char *argv[]) {
 	g_thread_init(NULL);
 	gdk_threads_init();	
 	gtk_init(&argc, &argv);
-	mainThread = g_thread_self();	/* we need to now this when locking in ui_queue.c */
+	mainThread = g_thread_self();	/* we need to know this for locking in ui_queue.c */
 
 	add_pixmap_directory(PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "pixmaps");
 
@@ -254,16 +266,20 @@ int main(int argc, char *argv[]) {
 		
 		/* order is important! */
 		conf_init();			/* initialize gconf */
-#ifdef USE_SM
-		session_init(BIN_DIR G_DIR_SEPARATOR_S "liferea", opt_session_arg);
-		session_set_cmd(NULL, startIconified);
-#endif
 		ui_htmlview_init();		/* setup HTML widgets */
 		download_init();		/* Initialize the download subsystem */
 		metadata_init();
 		feed_init();			/* register feed types */
 		conf_load();			/* load global feed settings */
-		ui_init(startIconified);	/* setup mainwindow and initialize gconf configured GUI behaviour */
+		ui_init(mainwindowState);	/* setup mainwindow and initialize gconf configured GUI behaviour */
+#ifdef USE_SM
+		/* This must be after feedlist reading because some session
+		   managers will tell Liferea to exit if Liferea does not
+		   respond to SM requests within a minute or two. This starts
+		   the main loop soon after opening the SM connection. */
+		session_init(BIN_DIR G_DIR_SEPARATOR_S "liferea", opt_session_arg);
+		session_set_cmd(NULL, mainwindowState);
+#endif
 		
 		gdk_threads_enter();
 		lifereaStarted = TRUE;
@@ -287,7 +303,7 @@ gboolean on_quit(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 	conf_feedlist_save();	/* should save feedlist and folder states */
 
 	/* should save all feeds still in memory */	
-	ui_feedlist_do_for_all(NULL, ACTION_FILTER_FEED | ACTION_FILTER_DIRECTORY, feed_unload);
+	ui_feedlist_do_for_all(NULL, ACTION_FILTER_FEED | ACTION_FILTER_DIRECTORY, feedlist_unload_feed);
 	
 	/* save pane proportions */
 	if(NULL != (pane = lookup_widget(mainwindow, "leftpane"))) {
