@@ -46,22 +46,22 @@ static gchar		*selectedURL = NULL;
 /* -------------------------------------------------------------------- */
 
 /* function to write HTML source into the widget */
-static void mozilla_write(GtkWidget *widget, const gchar *string, const gchar *base) {
+static void mozilla_write(GtkWidget *widget, const gchar *string, guint length, const gchar *base, const gchar *contentType) {
 
 	g_assert(NULL != widget);
 	
 	if(!GTK_WIDGET_REALIZED(widget)) 
 		return;
-
-	if((NULL != string) && (strlen(string) > 0)) {
+	
+	if((NULL != string) && (length > 0)) {
 		/* Because of a bug in Mozilla, sending the entire string at
 		   once causes Mozilla to hang. This seems to avoid that
 		   end. So many wasted hours finding the problem.... The
 		   result is in in the Mozilla Bugzilla. See report
 		   245960. Now off to eat dinner hours late because I missed
 		   the bus that I needed to use to get home. -Nathan*/
-		int left = strlen(string);
-		gtk_moz_embed_open_stream(GTK_MOZ_EMBED(widget), "file://", "text/html");
+		int left = length;
+		gtk_moz_embed_open_stream(GTK_MOZ_EMBED(widget), "file://", (contentType != NULL) ? contentType : "text/html");
 		while (left > 0) {
 			if (left > 4096) {
 				gtk_moz_embed_append_data(GTK_MOZ_EMBED(widget), string, 4096);
@@ -95,7 +95,7 @@ static void mozembed_new_window_cb(GtkMozEmbed *dummy, GtkMozEmbed **retval, gui
 	   are requested and the user crosses a link)  */
 	if(NULL != selectedURL) {
 		if(getBooleanConfValue(BROWSE_INSIDE_APPLICATION))
-			ui_tabs_new(selectedURL, selectedURL);
+			ui_tabs_new(selectedURL, selectedURL, FALSE);
 		else
 			ui_htmlview_launch_in_external_browser(selectedURL);
 	}
@@ -150,7 +150,7 @@ static gint mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event,
 	/* or a middle button click */
 	} else if(button == 1) {
 		if(NULL != selectedURL) {	
-			ui_tabs_new(selectedURL, selectedURL);
+			ui_tabs_new(selectedURL, selectedURL, FALSE);
 			return TRUE;
 		} else {
 			return FALSE;
@@ -254,6 +254,14 @@ static void mozilla_init() {
 	mozilla_preference_set_boolean("plugin.default_plugin_disabled", FALSE);
 	mozilla_preference_set_boolean("xpinstall.enabled", FALSE);
 	mozilla_preference_set_boolean("mozilla.widget.raise-on-setfocus", FALSE);
+
+	/* this prevents popup dialogs and gives IE-like HTML error pages instead */
+	mozilla_preference_set_boolean("browser.xul.error_pages.enabled", TRUE);
+
+	/* prevent typahead finding to allow Liferea keyboard navigation */
+	mozilla_preference_set_boolean("accessibility.typeaheadfind", FALSE);
+	mozilla_preference_set_boolean("accessibility.typeaheadfind.autostart", FALSE);
+
 	mozilla_save_prefs();
 }
 
