@@ -18,6 +18,10 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include "ns_ocs.h"
 #include "ocs_ns.h"
 #include "support.h"
