@@ -36,215 +36,6 @@
 #include "ui_notification.h"
 #include "itemlist.h"
 
-/**
- * Creates a new error description according to the passed
- * HTTP status and the feeds parser errors. If the HTTP
- * status is a success status and no parser errors occurred
- * no error messages is created. The created error message 
- * can be queried with feed_get_error_description().
- *
- * @param fp		feed
- * @param httpstatus	HTTP status
- * @param resultcode the update code's return code (see update.h)
- */
-static void ui_feed_set_error_description(feedPtr fp, gint httpstatus, gint resultcode, gchar *filterErrors) {
-	gchar		*tmp1, *tmp2 = NULL, *buffer = NULL;
-	gboolean	errorFound = FALSE;
-
-	g_assert(NULL != fp);
-	g_free(fp->errorDescription);
-	fp->errorDescription = NULL;
-	
-	if(((httpstatus >= 200) && (httpstatus < 400)) && /* HTTP codes starting with 2 and 3 mean no error */
-	   (NULL == filterErrors) && (NULL == fp->parseErrors))
-		return;
-	addToHTMLBuffer(&buffer, UPDATE_ERROR_START);
-	
-	if((200 != httpstatus) || (resultcode != NET_ERR_OK)) {
-		/* first specific codes */
-		switch(httpstatus) {
-			case 401:tmp2 = g_strdup(_("You are unauthorized to download this feed. Please update your username and "
-								  "password in the feed properties dialog box."));break;
-			case 402:tmp2 = g_strdup(_("Payment Required"));break;
-			case 403:tmp2 = g_strdup(_("Access Forbidden"));break;
-			case 404:tmp2 = g_strdup(_("Resource Not Found"));break;
-			case 405:tmp2 = g_strdup(_("Method Not Allowed"));break;
-			case 406:tmp2 = g_strdup(_("Not Acceptable"));break;
-			case 407:tmp2 = g_strdup(_("Proxy Authentication Required"));break;
-			case 408:tmp2 = g_strdup(_("Request Time-Out"));break;
-			case 410:tmp2 = g_strdup(_("Gone. Resource doesn't exist. Please unsubscribe!"));break;
-		}
-		/* Then, netio errors */
-		if(tmp2 == NULL) {
-			switch(resultcode) {
-			case NET_ERR_URL_INVALID:    tmp2 = g_strdup(_("URL is invalid")); break;
-			case NET_ERR_UNKNOWN:
-			case NET_ERR_CONN_FAILED:
-			case NET_ERR_SOCK_ERR:       tmp2 = g_strdup(_("Error connecting to remote host")); break;
-			case NET_ERR_HOST_NOT_FOUND: tmp2 = g_strdup(_("Hostname could not be found")); break;
-			case NET_ERR_CONN_REFUSED:   tmp2 = g_strdup(_("Network connection was refused by the remote host")); break;
-			case NET_ERR_TIMEOUT:        tmp2 = g_strdup(_("Remote host did not finish sending data")); break;
-				/* Transfer errors */
-			case NET_ERR_REDIRECT_COUNT_ERR: tmp2 = g_strdup(_("Too many HTTP redirects were encountered")); break;
-			case NET_ERR_REDIRECT_ERR:
-			case NET_ERR_HTTP_PROTO_ERR: 
-			case NET_ERR_GZIP_ERR:           tmp2 = g_strdup(_("Remote host sent an invalid response")); break;
-				/* These are handled above	
-				   case NET_ERR_HTTP_410:
-				   case NET_ERR_HTTP_404:
-				   case NET_ERR_HTTP_NON_200:
-				*/
-			case NET_ERR_AUTH_FAILED:
-			case NET_ERR_AUTH_NO_AUTHINFO: tmp2 = g_strdup(_("Authentication failed")); break;
-			case NET_ERR_AUTH_GEN_AUTH_ERR:
-			case NET_ERR_AUTH_UNSUPPORTED: tmp2 = g_strdup(_("Webserver's authentication method incompatible with Liferea")); break;
-			}
-		}
-		/* And generic messages in the unlikely event that the above didn't work */
-		if(NULL == tmp2) {
-			switch(httpstatus / 100) {
-			case 3:tmp2 = g_strdup(_("Feed not available: Server requested unsupported redirection!"));break;
-			case 4:tmp2 = g_strdup(_("Client Error"));break;
-			case 5:tmp2 = g_strdup(_("Server Error"));break;
-			default:tmp2 = g_strdup(_("(unknown networking error happened)"));break;
-			}
-		}
-		errorFound = TRUE;
-		tmp1 = g_strdup_printf(HTTP_ERROR_TEXT, httpstatus, tmp2);
-		addToHTMLBuffer(&buffer, tmp1);
-		g_free(tmp1);
-		g_free(tmp2);
-	}
-	
-	/* add filtering error messages */
-	if(NULL != filterErrors) {
-		if(errorFound)
-			addToHTMLBuffer(&buffer, HTML_NEWLINE);	
-		errorFound = TRUE;
-		tmp1 = g_markup_printf_escaped(FILTER_ERROR_TEXT, filterErrors);
-		addToHTMLBuffer(&buffer, tmp1);
-		g_free(tmp1);
-	}
-	
-	/* add parsing error messages */
-	if(NULL != fp->parseErrors) {
-		if(errorFound)
-			addToHTMLBuffer(&buffer, HTML_NEWLINE);	
-		errorFound = TRUE;
-		tmp1 = g_strdup_printf(PARSE_ERROR_TEXT, fp->parseErrors);
-		addToHTMLBuffer(&buffer, tmp1);
-		if (feed_get_source(fp) != NULL && (NULL != strstr(feed_get_source(fp), "://"))) {
-			xmlChar *escsource;
-			addToHTMLBufferFast(&buffer,_("<br>You may want to validate the feed using "
-									"<a href=\"http://feedvalidator.org/check.cgi?url="));
-			escsource = xmlURIEscapeStr(feed_get_source(fp),NULL);
-			addToHTMLBufferFast(&buffer,escsource);
-			xmlFree(escsource);
-			addToHTMLBuffer(&buffer,_("\">FeedValidator</a>."));
-		}
-		g_free(tmp1);
-	}
-	
-	/* if none of the above error descriptions matched... */
-	if(!errorFound) {
-		tmp1 = g_strdup_printf(_("There was a problem while reading this subscription. Please check the URL and console output."));
-		addToHTMLBuffer(&buffer, tmp1);
-		g_free(tmp1);
-	}
-	
-	addToHTMLBuffer(&buffer, UPDATE_ERROR_END);
-	fp->errorDescription = buffer;
-}
-
-/** handles completed feed update requests */
-void ui_feed_process_update_result(struct request *request) {
-	feedPtr			fp = (feedPtr)request->user_data;
-	feedHandlerPtr		fhp;
-	gchar			*old_title, *old_source;
-	gint			old_update_interval;
-	
-	g_assert(NULL != request);
-
-	feed_load(fp);
-
-	/* no matter what the result of the update is we need to save update
-	   status and the last update time to cache */
-	fp->needsCacheSave = TRUE;
-	
-	feed_set_available(fp, TRUE);
-
-	if(401 == request->httpstatus) { /* unauthorized */
-		feed_set_available(fp, FALSE);
-		if(request->flags & FEED_REQ_AUTH_DIALOG)
-			ui_feed_authdialog_new(GTK_WINDOW(mainwindow), fp, request->flags);
-	} else if(410 == request->httpstatus) { /* gone */
-		feed_set_available(fp, FALSE);
-		feed_set_discontinued(fp, TRUE);
-		ui_mainwindow_set_status_bar(_("\"%s\" is discontinued. Liferea won't updated it anymore!"), feed_get_title(fp));
-	} else if(304 == request->httpstatus) {
-		ui_mainwindow_set_status_bar(_("\"%s\" has not changed since last update"), feed_get_title(fp));
-	} else if(NULL != request->data) {
-		feed_set_lastmodified(fp, request->lastmodified);
-		feed_set_etag(fp, request->etag);
-		
-		/* note this is to update the feed URL on permanent redirects */
-		if(0 != strcmp(request->source, feed_get_source(fp))) {
-			feed_set_source(fp, request->source);
-			ui_mainwindow_set_status_bar(_("The URL of \"%s\" has changed permanently and was updated"), feed_get_title(fp));
-		}
-		
-		/* we save all properties that should not be overwritten in all cases */
-		old_update_interval = feed_get_update_interval(fp);
-		old_title = g_strdup(feed_get_title(fp));
-		old_source = g_strdup(feed_get_source(fp));
-
-		/* parse the new downloaded feed into new_fp */
-		fhp = feed_parse(fp, request->data, request->size, request->flags & FEED_REQ_AUTO_DISCOVER);
-		if(fhp == NULL) {
-			feed_set_available(fp, FALSE);
-			fp->parseErrors = g_strdup_printf(_("<p>Could not detect the type of this feed! Please check if the source really points to a resource provided in one of the supported syndication formats!</p>%s"), fp->parseErrors);
-		} else {
-			fp->fhp = fhp;
-			
-			/* restore user defined properties if necessary */
-			if(!(request->flags & FEED_REQ_RESET_TITLE))
-				feed_set_title(fp, old_title);
-				
-			if(!(request->flags & FEED_REQ_AUTO_DISCOVER))
-				feed_set_source(fp, old_source);
-
-			if(request->flags & FEED_REQ_RESET_UPDATE_INT)
-				feed_set_update_interval(fp, feed_get_default_update_interval(fp));
-			else
-				feed_set_update_interval(fp, old_update_interval);
-				
-			g_free(old_title);
-			g_free(old_source);
-
-			ui_mainwindow_set_status_bar(_("\"%s\" updated..."), feed_get_title(fp));
-
-			itemlist_reload((nodePtr)fp);
-			
-			if(request->flags & FEED_REQ_SHOW_PROPDIALOG)
-				ui_feed_propdialog_new(GTK_WINDOW(mainwindow),fp);
-		}
-	} else {	
-		ui_mainwindow_set_status_bar(_("\"%s\" is not available"), feed_get_title(fp));
-		feed_set_available(fp, FALSE);
-	}
-	
-	ui_feed_set_error_description(fp, request->httpstatus, request->returncode, request->filterErrors);
-
-	fp->request = NULL; 
-	ui_notification_update(fp);	
-	ui_feedlist_update();
-	
-	if(request->flags & FEED_REQ_DOWNLOAD_FAVICON)
-		favicon_download(fp);
-	
-	feed_unload(fp);
-}
-
 /** determines the feeds favicon or default icon */
 static GdkPixbuf* ui_feed_get_icon(feedPtr fp) {
 	gpointer	favicon;
