@@ -1,8 +1,8 @@
 /**
  * @file ui_itemlist.c Item list/view handling
  *  
- * Copyright (C) 2004 Lars Lindner <lars.lindner@gmx.net>
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2004-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004-2005 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -26,6 +26,7 @@
 
 #include <langinfo.h>
 #include <string.h>
+#include <gdk/gdkkeysyms.h>
 #include "support.h"
 #include "callbacks.h"
 #include "common.h"
@@ -57,14 +58,21 @@ static itemPtr ui_itemlist_get_selected();
 /* sort function for the item list date column */
 static gint timeCompFunc(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data) {
 	time_t	timea, timeb;
+	double diff;
 	
 	g_assert(model != NULL);
 	g_assert(a != NULL);
 	g_assert(b != NULL);
 	gtk_tree_model_get(model, a, IS_TIME, &timea, -1);
 	gtk_tree_model_get(model, b, IS_TIME, &timeb, -1);
+	diff = difftime(timeb,timea);
 	
-	return (-1)*(timeb-timea);
+	if (diff < 0)
+		return 1;
+	else if (diff > 0)
+		return -1;
+	else
+		return 0;
 }
 
 GtkTreeStore * ui_itemlist_get_tree_store(void) {
@@ -82,7 +90,7 @@ GtkTreeStore * ui_itemlist_get_tree_store(void) {
 			- feed icon
 		 */
 		itemstore = gtk_tree_store_new(IS_LEN,
-		                               G_TYPE_INT,
+		                               G_TYPE_ULONG,
 		                               G_TYPE_STRING, 
 		                               G_TYPE_STRING,
 					       G_TYPE_POINTER,
@@ -198,7 +206,6 @@ void ui_itemlist_clear(void) {
 }
 
 void ui_itemlist_update_item(itemPtr ip) {
-	GtkTreeStore	*itemstore = ui_itemlist_get_tree_store();
 	GtkTreeIter	*iter;
 	gchar		*title, *label, *time_str, *esc_title, *esc_time_str, *tmp;
 	GdkPixbuf	*icon = NULL, *favicon;
@@ -246,7 +253,7 @@ void ui_itemlist_update_item(itemPtr ip) {
 	g_free(esc_title);
 	g_free(esc_time_str);
 	
-	if(TRUE == item_get_flag(ip)) 
+	if(TRUE == item_get_flag_status(ip)) 
 		icon = icons[ICON_FLAG];
 
 	/* Finish 'em... */
@@ -275,6 +282,16 @@ void ui_itemlist_update(void) {
 	g_hash_table_foreach(iterhash, ui_itemlist_update_foreach, NULL);
 }
 
+static gboolean ui_itemlist_key_press_cb(GtkWidget *widget, GdkEventKey *event, gpointer data) {
+
+	if((event->type == GDK_KEY_PRESS) &&
+	   (event->state == 0) &&
+	   (event->keyval == GDK_Delete)) {
+		on_remove_item_activate(NULL, NULL);
+	}
+	return FALSE;
+}
+
 void ui_itemlist_init(GtkWidget *itemlist) {
 	GtkCellRenderer		*renderer;
 	GtkTreeViewColumn 	*column;
@@ -314,6 +331,9 @@ void ui_itemlist_init(GtkWidget *itemlist) {
 	gtk_tree_view_column_set_sort_column_id(column, IS_LABEL);
 
 	g_object_set(column, "resizable", TRUE, NULL);
+
+	/* And connect signals */	
+	g_signal_connect(G_OBJECT(GTK_TREE_VIEW(itemlist)), "key-press-event", G_CALLBACK(ui_itemlist_key_press_cb), NULL);
 	
 	/* Setup the selection handler */
 	select = gtk_tree_view_get_selection(GTK_TREE_VIEW(itemlist));
@@ -381,7 +401,7 @@ void ui_itemlist_display(void) {
 		if(TRUE == ui_itemlist_get_two_pane_mode()) {
 			/* two pane mode */
 			ui_htmlview_start_output(&buffer, base, FALSE);
-				
+			
 			valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(itemstore), &iter);
 			while(valid) {	
 				ip = ui_itemlist_get_item_from_iter(&iter);
@@ -502,11 +522,16 @@ void on_popup_launchitem_selected(void) {
 
 void on_popup_launchitem_in_tab_selected(void) {
 	itemPtr		ip;
+	const gchar	*link;
 
-	if(NULL != (ip = ui_itemlist_get_selected()))
-		ui_tabs_new(item_get_source(ip), item_get_source(ip));
-	else
+	if(NULL != (ip = ui_itemlist_get_selected())) {
+		if(NULL != (link = item_get_source(ip)))
+			ui_tabs_new(link, link, FALSE);
+		else
+			ui_show_error_box(_("This item has no link specified!"));
+	} else {
 		ui_mainwindow_set_status_bar(_("No item has been selected"));
+	}
 }
 
 void on_Itemlist_row_activated(GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, gpointer user_data) {
@@ -584,24 +609,66 @@ static void ui_itemlist_select(GtkTreeIter iter) {
 	}
 }
 
-static gboolean ui_itemlist_find_unread_item(void) {
-	GtkTreeStore		*itemstore = ui_itemlist_get_tree_store();
-	GtkTreeIter		iter;
-	gboolean		valid;
-	itemPtr			ip;
-		
-	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(itemstore), &iter);
-	while(valid) {
-		ip = ui_itemlist_get_item_from_iter(&iter);
-		if(FALSE == item_get_read_status(ip)) {
-			if(!ui_itemlist_get_two_pane_mode()) {
-				ui_itemlist_select(iter);
-				itemlist_set_read_status(ip, TRUE);	/* needed when no selection happens (e.g. when the item is already selected) */
-			} else {
-				itemlist_mark_all_read((nodePtr)ip->fp);
-			}
-			return TRUE;
+static gint iter_cmp(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b) {
+	GtkTreePath             *apath, *bpath;
+	gint			ret;
+	
+	apath = gtk_tree_model_get_path(model, a);
+	bpath = gtk_tree_model_get_path(model, b);
+	ret = gtk_tree_path_compare(apath, bpath);
+	gtk_tree_path_free(apath);
+	gtk_tree_path_free(bpath);
+	return ret;
+}
+
+static gboolean ui_itemlist_find_unread_item_from_iter(GtkTreeIter *iter) {
+	itemPtr	ip;
+	
+	ip = ui_itemlist_get_item_from_iter(iter);
+	if(FALSE == item_get_read_status(ip)) {
+		if(!ui_itemlist_get_two_pane_mode()) {
+			ui_itemlist_select(*iter);
+			itemlist_set_read_status(ip, TRUE);	/* needed when no selection happens (e.g. when the item is already selected) */
+		} else {
+			itemlist_mark_all_read((nodePtr)ip->fp);
 		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
+static gboolean ui_itemlist_find_unread_item(void) {
+	GtkTreeView		*treeview;
+	GtkTreeStore		*itemstore;
+	GtkTreePath		*path;
+	GtkTreeIter		iter, selectedIter;
+	gboolean		valid;
+
+	itemstore = ui_itemlist_get_tree_store();
+	
+	/* first look for unread items after the currently selected item */
+	treeview = GTK_TREE_VIEW(lookup_widget(mainwindow, "Itemlist"));
+	gtk_tree_view_get_cursor(treeview, &path, NULL);
+	
+	if(NULL != path) {
+		gtk_tree_model_get_iter(GTK_TREE_MODEL(itemstore), &selectedIter, path);
+		valid = gtk_tree_model_get_iter(GTK_TREE_MODEL(itemstore), &iter, path);
+		gtk_tree_path_free(path);
+
+		while(valid) {
+			if(ui_itemlist_find_unread_item_from_iter(&iter))
+				return TRUE;
+			valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(itemstore), &iter);
+		}
+	} else {
+		gtk_tree_model_get_iter_first(GTK_TREE_MODEL(itemstore), &selectedIter);
+	}
+	
+	/* No match from cursor, restart from the first. */
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(itemstore), &iter);
+	while(valid && (0 != iter_cmp(GTK_TREE_MODEL(itemstore), &iter, &selectedIter))) {
+		if(ui_itemlist_find_unread_item_from_iter(&iter))
+			return TRUE;
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(itemstore), &iter);
 	}
 
@@ -641,7 +708,6 @@ void on_nextbtn_clicked(GtkButton *button, gpointer user_data) {
 }
 
 gboolean on_itemlist_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data) {
-	GtkTreeStore		*itemstore = ui_itemlist_get_tree_store();
 	GdkEventButton		*eb;
 	GtkWidget		*treeview;
 	GtkTreeViewColumn	*column;
@@ -699,10 +765,18 @@ void ui_itemlist_set_two_pane_mode(gboolean new_mode) {
 	old_mode = ui_itemlist_get_two_pane_mode();
 	ui_mainwindow_set_three_pane_mode(!new_mode);
 
-	if(new_mode != old_mode)
+	if(new_mode != old_mode) {
+		/* Disconnect signal so that this will not cause the itemlist
+		   to be redrawn. This would happen since
+		   on_toggle_condensed_view_activate would have been
+		   called. */
+		g_signal_handlers_block_by_func(lookup_widget(mainwindow, "toggle_condensed_view"), G_CALLBACK (on_toggle_condensed_view_activate), NULL);
 		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(lookup_widget(mainwindow, "toggle_condensed_view")), new_mode);
+		g_signal_handlers_unblock_by_func(lookup_widget(mainwindow, "toggle_condensed_view"), G_CALLBACK (on_toggle_condensed_view_activate), NULL);
+	}
 }
 
+/* This is the callback for the menu option to switch between two and three pane modes */
 void on_toggle_condensed_view_activate(GtkMenuItem *menuitem, gpointer user_data) { 
 	nodePtr		np;
 	
@@ -716,3 +790,12 @@ void on_toggle_condensed_view_activate(GtkMenuItem *menuitem, gpointer user_data
 		itemlist_load(np);
 	}
 }
+
+void on_popup_copy_URL_clipboard(void) {
+	itemPtr         ip;
+
+	if(NULL != (ip = ui_itemlist_get_selected()))
+		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD), item_get_source(ip), -1);
+	else
+		ui_mainwindow_set_status_bar(_("No item has been selected"));
+}
