@@ -1,8 +1,8 @@
 /**
  * @file ui_mainwindow.c some functions concerning the main window 
  *
- * Copyright (C) 2004 Nathan J. Conrad <t98502@users.sourceforge.net>
- * Copyright (C) 2004 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004-2005 Nathan J. Conrad <t98502@users.sourceforge.net>
+ * Copyright (C) 2004-2005 Lars Lindner <lars.lindner@gmx.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -68,8 +68,6 @@ GtkWidget 	*mainwindow;
 
 static GtkWidget *htmlview = NULL;		/* HTML rendering widget */
 static gfloat 	zoom;				/* HTML rendering widget zoom level */
-static int trayCount = 0;
-extern gboolean	startIconified; /* From main.c */
 
 /* some prototypes */
 static void ui_mainwindow_restore_position(GtkWidget *window);
@@ -81,34 +79,111 @@ GtkWidget *ui_mainwindow_get_active_htmlview(void) {
 
 extern htmlviewPluginInfo *htmlviewInfo;
 
+/*------------------------------------------------------------------------------*/
+/* keyboard navigation	 							*/
+/*------------------------------------------------------------------------------*/
+
+/* Set cursor to the first item on a treeview. */
+static void on_treeview_set_first(char* treename) {
+	GtkTreeView	*treeview;
+	GtkTreePath	*path;
+
+	treeview = GTK_TREE_VIEW(lookup_widget(mainwindow, treename));
+	path = gtk_tree_path_new_first();
+	gtk_tree_view_set_cursor(treeview, path, NULL, FALSE);
+	gtk_tree_path_free(path);
+}
+
+/* Move treeview cursor up and down. */
+static void on_treeview_move(char* treename, gint step) {
+	GtkTreeView	*treeview;
+	gboolean	ret;
+
+	treeview = GTK_TREE_VIEW(lookup_widget(mainwindow, treename));
+	gtk_widget_grab_focus(GTK_WIDGET(treeview));
+	g_signal_emit_by_name(treeview, "move-cursor", GTK_MOVEMENT_DISPLAY_LINES, step, &ret);
+}
+
+static void on_treeview_prev(char* treename) {
+	on_treeview_move(treename, -1);
+}
+
+static void on_treeview_next(char* treename) {
+	on_treeview_move(treename, 1);
+}
+
 gboolean on_mainwindow_key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data) {
-	gboolean modifier_matches = FALSE;
+	gboolean	modifier_matches = FALSE;
+	guint		default_modifiers;
+	const gchar	*type;
+	GtkWidget	*focusw;
 
-	if((event->type == GDK_KEY_PRESS) &&
-	   (event->keyval == GDK_space)) {
-
-		switch(getNumericConfValue(BROWSE_KEY_SETTING)) {
-			case 0:
-				modifier_matches = ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK);
-				break;
-			default:
-			case 1:
-				modifier_matches = (0 == event->state);
-				if(!strcmp(htmlviewInfo->name, "Mozilla")) /* Hack to make space handled in the module */
-					return FALSE;
-				break;
-			case 2:
-				modifier_matches = ((event->state & GDK_MOD1_MASK) == GDK_MOD1_MASK);
-				break;
+	if(event->type == GDK_KEY_PRESS) {
+		/* handle headline skimming hotkey */
+		if(event->keyval == GDK_space) {
+			switch(getNumericConfValue(BROWSE_KEY_SETTING)) {
+				case 0:
+					modifier_matches = ((event->state & GDK_CONTROL_MASK) == GDK_CONTROL_MASK);
+					break;
+				default:
+				case 1:
+					default_modifiers = gtk_accelerator_get_default_mod_mask();
+					modifier_matches = ((event->state & default_modifiers) == 0);
+					if(!strcmp(htmlviewInfo->name, "Mozilla")) /* Hack to make space handled in the module */
+						return FALSE;
+					break;
+				case 2:
+					modifier_matches = ((event->state & GDK_MOD1_MASK) == GDK_MOD1_MASK);
+					break;
+			}
+			
+			if(modifier_matches) {
+				/* Note that this code is duplicated in mozilla/mozilla.cpp! */
+				if(ui_htmlview_scroll() == FALSE)
+					on_next_unread_item_activate(NULL, NULL);
+				return TRUE;
+			}
 		}
-		
-		if(modifier_matches) {
-			/* Note that this code is duplicated in mozilla/mozilla.cpp! */
-			if(ui_htmlview_scroll() == FALSE)
+
+		/* prevent usage of navigation keys in entries */
+		focusw = gtk_window_get_focus(GTK_WINDOW(widget));
+		if(GTK_IS_ENTRY(focusw))
+			return FALSE;
+
+		/* prevent usage of navigation keys in HTML view */
+		type = g_type_name(GTK_WIDGET_TYPE(focusw));
+		if((NULL != type) && (0 == strcmp(type, "MozContainer")))
+			return FALSE;
+
+		/* somehow we don't need to check for GtkHTML2... */
+
+		/* check for treeview navigation */
+		switch (event->keyval) {
+			case GDK_n: 
 				on_next_unread_item_activate(NULL, NULL);
-			return TRUE;
+				return TRUE;
+				break;
+			case GDK_f:
+				on_treeview_next("Itemlist");
+				return TRUE;
+				break;
+			case GDK_b:
+				on_treeview_prev("Itemlist");
+				return TRUE;
+				break;
+			case GDK_u:
+				on_treeview_prev("feedlist");
+				on_treeview_set_first("Itemlist");
+				return TRUE;
+				break;
+			case GDK_d:
+				on_treeview_next("feedlist");
+				on_treeview_set_first("Itemlist");
+				return TRUE;
+				break;
 		}
 	}
+	
 	return FALSE;
 }
 
@@ -148,6 +223,32 @@ void ui_mainwindow_set_toolbar_style(GtkWindow *window, const gchar *toolbar_sty
 	
 }
 
+static gboolean on_key_press_event_null_cb(GtkWidget *widget, GdkEventKey *event, gpointer data) {
+	return TRUE;
+}
+
+static gboolean
+on_notebook_scroll_event_null_cb (GtkWidget *widget, GdkEventScroll *event)
+{
+	GtkNotebook *notebook = GTK_NOTEBOOK (widget);
+
+	GtkWidget* child;
+	GtkWidget* originator;
+
+	if (!notebook->cur_page)
+		return FALSE;
+
+	child = gtk_notebook_get_nth_page(notebook, gtk_notebook_get_current_page(notebook));
+	originator = gtk_get_event_widget ((GdkEvent *)event);
+
+	/* ignore scroll events from the content of the page */
+	if (!originator || gtk_widget_is_ancestor (originator, child))
+		return FALSE;
+
+	return TRUE;
+}
+
+
 GtkWidget* ui_mainwindow_new(void) {
 
 	GtkWidget *window = create_mainwindow();
@@ -164,6 +265,16 @@ GtkWidget* ui_mainwindow_new(void) {
 	TOOLBAR_ADD(toolbar,  _("Update All"), GTK_STOCK_REFRESH, tooltips,  _("Updates all subscriptions. This does not update OCS directories."), on_refreshbtn_clicked);
 	TOOLBAR_ADD(toolbar,  _("Search"), GTK_STOCK_FIND, tooltips,  _("Search all feeds."), on_searchbtn_clicked);
 	TOOLBAR_ADD(toolbar,  _("Preferences"), GTK_STOCK_PREFERENCES, tooltips,  _("Edit preferences."), on_prefbtn_clicked);
+
+	g_signal_connect ((gpointer) lookup_widget(window, "itemtabs"), "key_press_event",
+					  G_CALLBACK (on_key_press_event_null_cb), NULL);
+
+	g_signal_connect ((gpointer) lookup_widget(window, "itemtabs"), "key_release_event",
+					  G_CALLBACK (on_key_press_event_null_cb), NULL);
+	
+	g_signal_connect ((gpointer) lookup_widget(window, "itemtabs"), "scroll_event",
+                      G_CALLBACK (on_notebook_scroll_event_null_cb), NULL);
+	
 	gtk_widget_show_all(GTK_WIDGET(toolbar));
 
 	ui_mainwindow_restore_position(window);
@@ -174,9 +285,13 @@ GtkWidget* ui_mainwindow_new(void) {
 void ui_mainwindow_finish(GtkWidget *window) {
 	gchar	*buffer = NULL;
 
+	ui_mainwindow_set_three_pane_mode(FALSE); /* Initializes the htmlviews */
+
 	/* force two pane mode */
+	/*   For some reason, this causes the first item to be selected and then
+	     unselected... strange. */
 	ui_feedlist_select(NULL);
-	ui_itemlist_set_two_pane_mode(TRUE);
+	itemlist_set_two_pane_mode(TRUE);
 	
 	/* set zooming properties */	
 	zoom = getNumericConfValue(LAST_ZOOMLEVEL)/100.;
@@ -213,7 +328,7 @@ void ui_mainwindow_finish(GtkWidget *window) {
 	                           "of a subscription.</p></li>"
 	                           "</ul>"
 	                           "<p>To learn more about Liferea you should read the documentation "
-	                           "provided in the help feed or in the <a href=\"http://liferea.sourceforge.net/faq.php\">FAQ</a> available at the "
+	                           "provided in the help feed or in the <a href=\"http://liferea.sourceforge.net/faq.htm\">FAQ</a> available at the "
 	                           "<a href=\"http://liferea.sf.net\">project homepage</a>.</p>"));
 	ui_htmlview_finish_output(&buffer);
 	ui_htmlview_write(ui_mainwindow_get_active_htmlview(), buffer, NULL);
@@ -346,18 +461,15 @@ void ui_mainwindow_save_position(void) {
 }
 
 void ui_mainwindow_tray_add() {
-	trayCount++;
+
 }
 
 void ui_mainwindow_tray_remove() {
-	trayCount--;
 	
-	if (trayCount == 0)
+	if (ui_tray_get_count() == 0)
 		if (!GTK_WIDGET_VISIBLE(mainwindow)) {
 			ui_mainwindow_restore_position(mainwindow);
 			gtk_window_present(GTK_WINDOW(mainwindow));
-			if (!startIconified)
-				session_set_cmd(NULL, FALSE);
 		}
 }
 
@@ -405,86 +517,44 @@ static void ui_mainwindow_restore_position(GtkWidget *window) {
  * Feed menu callbacks
  */
 
-void on_menu_feed_new(GtkMenuItem *menuitem, gpointer user_data) {
-	on_newbtn_clicked(NULL, NULL);
-}
-
-void on_menu_feed_update(GtkMenuItem *menuitem, gpointer user_data) {
-	feedPtr fp = (feedPtr)ui_feedlist_get_selected();
-
-	on_popup_refresh_selected((gpointer)fp, 0, NULL);
-}
-
-void on_menu_folder_new(GtkMenuItem *menuitem, gpointer user_data) {
-
-	on_popup_newfolder_selected();
-}
-
-void on_menu_delete(GtkMenuItem *menuitem, gpointer user_data) {
-	nodePtr ptr = (nodePtr)ui_feedlist_get_selected();
-
-	ui_feedlist_delete(ptr);
-}
-
-void on_menu_properties(GtkMenuItem *menuitem, gpointer user_data) {
-	nodePtr ptr = ui_feedlist_get_selected();
-	
-	if((ptr != NULL) && (FST_FOLDER == ptr->type)) {
-		on_popup_foldername_selected((gpointer)ptr, 0, NULL);
-	} else if((ptr != NULL) && (FST_FEED == ptr->type)) {
-		on_popup_prop_selected((gpointer)ptr, 0, NULL);
-	} else {
-		g_warning("You have found a bug in Liferea. You must select a node in the feedlist to do what you just did.");
-	}
-}
-
-
-void on_menu_update(GtkMenuItem *menuitem, gpointer user_data) {
-	nodePtr ptr = ui_feedlist_get_selected();
-	
-	if (ptr != NULL) {
-		on_popup_refresh_selected((gpointer)ptr, 0, NULL);
-	} else {
-		g_warning("You have found a bug in Liferea. You must select a node in the feedlist to do what you just did.");
-	}
-}
-
 gboolean on_close(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
-
-	if(trayCount == 0)
+	
+	if(ui_tray_get_count() == 0)
 		return on_quit(widget, event, user_data);
 	ui_mainwindow_save_position();
 	gtk_widget_hide(mainwindow);
-	if (!startIconified)
-		session_set_cmd(NULL, TRUE);
 	return TRUE;
 }
 
 void ui_mainwindow_toggle_visibility(GtkMenuItem *menuitem, gpointer data) {
-
+	
 	if((gdk_window_get_state(GTK_WIDGET(mainwindow)->window) & GDK_WINDOW_STATE_ICONIFIED) || !GTK_WIDGET_VISIBLE(mainwindow)) {
 		ui_mainwindow_restore_position(mainwindow);
 		gtk_window_present(GTK_WINDOW(mainwindow));
-		if (!startIconified)
-			session_set_cmd(NULL, FALSE);
 	} else {
 		ui_mainwindow_save_position();
 		gtk_widget_hide(mainwindow);
-		if (!startIconified)
-			session_set_cmd(NULL, TRUE);
 	}
 }
 
 gboolean on_mainwindow_window_state_event(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
-	
-	if(!GTK_WIDGET_VISIBLE(mainwindow))
-		return FALSE;
-	
 	if((event->type) == (GDK_WINDOW_STATE)) {
-		if((((GdkEventWindowState*)event)->new_window_state) & GDK_WINDOW_STATE_MAXIMIZED)
-			setBooleanConfValue(LAST_WINDOW_MAXIMIZED, TRUE);
+		GdkWindowState changed = ((GdkEventWindowState*)event)->changed_mask, state = ((GdkEventWindowState*)event)->new_window_state;
+	
+		//if(!GTK_WIDGET_VISIBLE(mainwindow))
+		//return FALSE;
+		if (changed == GDK_WINDOW_STATE_MAXIMIZED) {
+			if(state & GDK_WINDOW_STATE_MAXIMIZED)
+				setBooleanConfValue(LAST_WINDOW_MAXIMIZED, TRUE);
+			else
+				setBooleanConfValue(LAST_WINDOW_MAXIMIZED, FALSE);
+		}
+		if(state & GDK_WINDOW_STATE_ICONIFIED)
+			session_set_cmd(NULL, MAINWINDOW_ICONIFIED);
+		else if(state & GDK_WINDOW_STATE_WITHDRAWN)
+			session_set_cmd(NULL, MAINWINDOW_HIDDEN);
 		else
-			setBooleanConfValue(LAST_WINDOW_MAXIMIZED, FALSE);
+			session_set_cmd(NULL, MAINWINDOW_SHOWN);
 	}
 	return FALSE;
 }
@@ -540,7 +610,7 @@ static void ui_choose_file_or_dir(gchar *title, GtkWindow *parent, gchar *button
 	GtkWidget			*button;
 
 	g_assert(TRUE != (saving & directory));
-g_print("file/dir chooser: saving=%s directory=%s currentFile=%s file=%s data=%d\n", saving?"TRUE":"FALSE", directory?"TRUE":"FALSE", currentFilename, filename, user_data);
+
 #if GTK_CHECK_VERSION(2,4,0)
 	dialog = gtk_file_chooser_dialog_new(title,
 	                                     parent,
@@ -604,4 +674,3 @@ void ui_choose_directory(gchar *title, GtkWindow *parent, gchar *buttonName, fil
 
 	ui_choose_file_or_dir(title, parent, buttonName, FALSE, TRUE, callback, currentFilename, filename, user_data);
 }
-
