@@ -32,6 +32,7 @@
 #include "support.h"
 #include "common.h"
 
+extern GtkWidget	*mainwindow;
 static GtkWidget	*searchdialog = NULL;
 static GtkWidget 	*feedsterdialog = NULL;
 static feedPtr		searchFeed = NULL;
@@ -40,12 +41,23 @@ static feedPtr		searchFeed = NULL;
 /* search dialog callbacks							*/
 /*------------------------------------------------------------------------------*/
 
+static void ui_search_destroyed_cb(GtkWidget *widget, void *data) {
+
+	searchdialog = NULL;
+}
+
 void on_searchbtn_clicked(GtkButton *button, gpointer user_data) {
+	GtkWidget	*searchentry;
 	gboolean	visible;
 
-	if(NULL == searchdialog)
+	if(NULL == searchdialog) {
 		searchdialog = create_searchdialog();
+		gtk_window_set_transient_for(GTK_WINDOW(searchdialog), GTK_WINDOW(mainwindow));
+		g_signal_connect(G_OBJECT(searchdialog), "destroy", G_CALLBACK(ui_search_destroyed_cb), NULL);
+	}
 	
+	searchentry = lookup_widget(searchdialog, "searchentry");
+	gtk_window_set_focus(GTK_WINDOW(searchdialog), searchentry);
 	g_object_get(searchdialog, "visible", &visible, NULL);
 	g_object_set(searchdialog, "visible", !visible, NULL);
 }
@@ -72,10 +84,12 @@ void on_searchentry_activate(GtkEntry *entry, gpointer user_data) {
 	vfolder_add_rule(searchFeed, "exact", searchstring, TRUE);
 	vfolder_refresh(searchFeed);
 	ui_feedlist_select(NULL);
+
+	/* switch to item list view and inform user in HTML view */
+	itemlist_set_two_pane_mode(FALSE);
+
 	itemlist_load((nodePtr)searchFeed);
 	
-	/* switch to item list view and inform user in HTML view */
-	ui_itemlist_set_two_pane_mode(FALSE);
 
 	ui_htmlview_start_output(&buffer, NULL, TRUE);
 	tmp = g_strdup_printf(_("%s<h2>%d Search Results for \"%s\"</h2>"
@@ -112,7 +126,7 @@ void on_newVFolder_clicked(GtkButton *button, gpointer user_data) {
 		folder = ui_feedlist_get_target_folder(&pos);
 		fp = searchFeed;
 		searchFeed = NULL;
-		ui_feedlist_add(folder, (nodePtr)fp, pos);
+		feedlist_add_feed(folder, (feedPtr)fp, pos);
 		ui_feedlist_update();
 		ui_feedlist_select((nodePtr)fp);
 	} else {
@@ -128,7 +142,7 @@ void on_new_vfolder_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	fp = vfolder_new();
 	feed_set_title(fp, _("New VFolder"));
 	folder = ui_feedlist_get_target_folder(&pos);
-	ui_feedlist_add(folder, (nodePtr)fp, pos);
+	feedlist_add_feed(folder, (feedPtr)fp, pos);
 	ui_feedlist_update();
 	ui_feedlist_select((nodePtr)fp);
 }
@@ -158,14 +172,22 @@ void on_feedsterbtn_clicked(GtkButton *button, gpointer user_data) {
 	}
 }
 
+static void ui_feedster_destroyed_cb(GtkWidget *widget, void *data) {
+
+	feedsterdialog = NULL;
+}
+
 void on_search_with_feedster_activate(GtkMenuItem *menuitem, gpointer user_data) {
 	GtkWidget	*keywords;
 	
-	if(NULL == feedsterdialog || !G_IS_OBJECT(feedsterdialog))
+	if(NULL == feedsterdialog) {
 		feedsterdialog = create_feedsterdialog();
+		gtk_window_set_transient_for(GTK_WINDOW(feedsterdialog), GTK_WINDOW(mainwindow));
+		g_signal_connect(G_OBJECT(feedsterdialog), "destroy", G_CALLBACK(ui_feedster_destroyed_cb), NULL);
+	}
 		
 	keywords = lookup_widget(feedsterdialog, "feedsterkeywords");
+	gtk_window_set_focus(GTK_WINDOW(feedsterdialog), keywords);
 	gtk_entry_set_text(GTK_ENTRY(keywords), "");
 	gtk_widget_show(feedsterdialog);
 }
-
