@@ -1,23 +1,23 @@
-/*
-   tray icon handling
-   
-   Copyright (C) 2003 Lars Lindner <lars.lindner@gmx.net>
-   Copyright (C) 2004 Christophe Barbe <christophe.barbe@ufies.org>
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
-   (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
+/**
+ * @file ui_tray.c tray icon handling
+ * 
+ * Copyright (C) 2003-2005 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2004 Christophe Barbe <christophe.barbe@ufies.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -30,6 +30,7 @@
 #include "callbacks.h"
 #include "eggtrayicon.h"
 #include "support.h"
+#include "feedlist.h"
 #include "ui_tray.h"
 #include "ui_popup.h"
 #include "ui_mainwindow.h"
@@ -42,15 +43,16 @@ extern GdkPixbuf	*icons[];
 extern GtkWidget	*mainwindow;
 
 static GtkWidget	*eventbox = NULL;
-static gint		newItems = 0;
 static EggTrayIcon 	*tray_icon =  NULL;
 static GtkTooltips	*tray_icon_tips = NULL;
 static GtkWidget	*image = NULL;		/* the image in the notification area */
+static int trayCount = 0;
 
 static void installTrayIcon(void);
 
 void ui_tray_tooltip_set(gchar *message) {
 	GtkTooltipsData	*data = NULL;
+	
 	g_assert(tray_icon_tips);
 
 	data = gtk_tooltips_data_get(GTK_WIDGET(tray_icon));
@@ -72,6 +74,7 @@ void ui_tray_tooltip_set(gchar *message) {
 }
 
 static void ui_tray_icon_set(GdkPixbuf *icon) {
+
 	g_assert(tray_icon);
 
 	if(NULL != image)
@@ -82,30 +85,28 @@ static void ui_tray_icon_set(GdkPixbuf *icon) {
 	gtk_widget_show_all(GTK_WIDGET(tray_icon));
 }
 
-void ui_tray_add_new(gint count) {
-	gchar *msg;
+void ui_tray_update(void) {
+	gint	newItems, unreadItems;
+	gchar	*msg, *tmp;
+	
 	if(!tray_icon)
 		return;
+
+	newItems = feedlist_get_new_item_count();
+	unreadItems = feedlist_get_unread_item_count();
 		
-	if(count > 0) {
+	if(newItems != 0) {
 		ui_tray_icon_set(icons[ICON_AVAILABLE]); 
-		newItems += count;
-		msg = g_strdup_printf(ngettext("%d new item!", "%d new items!", newItems), newItems);
-		ui_tray_tooltip_set(msg);
-		g_free(msg);
-	}
-}
-
-void ui_tray_zero_new(void) {
-
-	if(!tray_icon)
-		return;
-		
-	if(0 != newItems) {
+		tmp = g_strdup_printf(ngettext("%d new item", "%d new items", newItems), newItems);
+		msg = g_strdup_printf(ngettext("%s\n%d unread item", "%s\n%d unread items", unreadItems), tmp, unreadItems);
+	} else {
 		ui_tray_icon_set(icons[ICON_EMPTY]);
-		ui_tray_tooltip_set(_("No new items."));
-		newItems = 0;
+		tmp = g_strdup(_("No new items"));
+		msg = g_strdup_printf(ngettext("%s\n%d unread item", "%s\n%d unread items", unreadItems), tmp, unreadItems);
 	}
+	ui_tray_tooltip_set(msg);
+	g_free(tmp);
+	g_free(msg);
 }
 
 /* a click on the systray icon should show the program window
@@ -123,8 +124,9 @@ static void tray_icon_pressed(GtkWidget *button, GdkEventButton *event, EggTrayI
 						  
 	return;
 }
-static gboolean ui_tray_create_cb()
-{
+
+static gboolean ui_tray_create_cb() {
+
 	installTrayIcon();
 	
 	return FALSE; /* for when we're called by the glib idle handler */
@@ -132,15 +134,19 @@ static gboolean ui_tray_create_cb()
 
 
 static void ui_tray_embedded_cb(GtkWidget *widget, void *data) {
+
+	trayCount++;
 	ui_mainwindow_tray_add();
 }
 
 
 static void ui_tray_destroyed_cb(GtkWidget *widget, void *data) {
+
 	g_object_unref(G_OBJECT(tray_icon));
 
 	image = NULL;
 	tray_icon = NULL;
+	trayCount--;
 	ui_mainwindow_tray_remove();
 	
 	/* And make it re-appear when the notification area reappears */
@@ -149,7 +155,8 @@ static void ui_tray_destroyed_cb(GtkWidget *widget, void *data) {
 }
 
 static void installTrayIcon(void) {
-	g_assert(!tray_icon);
+
+	g_assert(NULL == tray_icon);
 
 	tray_icon = egg_tray_icon_new(PACKAGE);
 	eventbox = gtk_event_box_new();
@@ -164,29 +171,34 @@ static void installTrayIcon(void) {
 	g_object_ref(G_OBJECT(tray_icon));
 	
 	tray_icon_tips = gtk_tooltips_new();
-	newItems = -1;
-	ui_tray_zero_new();
+	ui_tray_update();
 }
 
 static void removeTrayIcon() {
+
 	g_assert(tray_icon != NULL);
 	
 	g_signal_handlers_disconnect_by_func(G_OBJECT(tray_icon), G_CALLBACK(ui_tray_destroyed_cb), NULL);
 	gtk_widget_destroy(image);
 	image = NULL;
 	g_object_unref(G_OBJECT(tray_icon));
-	gtk_object_destroy (GTK_OBJECT (tray_icon));
+	gtk_object_destroy(GTK_OBJECT (tray_icon));
 	tray_icon = NULL;
+	trayCount--;
 	ui_mainwindow_tray_remove();
 }
 
 void ui_tray_enable(gboolean enabled) {
+
 	if(enabled) {
-		if (tray_icon == NULL)
+		if(tray_icon == NULL)
 			installTrayIcon();
 	} else {
-		if (tray_icon != NULL) {
+		if(tray_icon != NULL)
 			removeTrayIcon();
-		}
 	}
 }
+
+int ui_tray_get_count() {
+	return trayCount;
+}
