@@ -66,8 +66,8 @@ static char* filter(gchar *cmd, gchar *data, gchar **errorOutput, size_t *size)
 	fd = g_mkstemp(tmpfilename);
 	
 	if (fd == -1) {
-		odebug1("Error opening temp file %s to use for filtering!", tmpfilename);
-		*errorOutput = g_strdup_printf("Error opening temp file %s to use for filtering!", tmpfilename);
+		debug1(DEBUG_UPDATE, "Error opening temp file %s to use for filtering!", tmpfilename);
+		*errorOutput = g_strdup_printf(_("Error opening temp file %s to use for filtering!"), tmpfilename);
 		g_free(tmpfilename);
 		return NULL;
 	}	
@@ -136,7 +136,7 @@ void download_process(struct request *request) {
 			ui_mainwindow_set_status_bar(_("Error: Could not open pipe \"%s\""), (request->source) + 1);
 			request->httpstatus = 404;	/* FIXME: maybe setting request->returncode would be better */
 		}
-	} else if(NULL != strstr(request->source, "://")) {
+	} else if(NULL != strstr(request->source, "://") && strncmp(request->source, "file://",7)) {
 		/* just a web URL */
 		downloadlib_process_url(request);
 		if(request->httpstatus >= 400) {
@@ -145,17 +145,21 @@ void download_process(struct request *request) {
 			request->size = 0;
 		}
 	} else {
-		if(g_file_test(request->source, G_FILE_TEST_EXISTS)) {
+		gchar *filename = request->source;
+		if (!strncmp(request->source, "file://",7))
+			filename = &(filename[7]);
+		
+		if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
 			/* we have a file... */
-			if((!g_file_get_contents(request->source, &(request->data), &(request->size), NULL)) || (request->data[0] == '\0')) {
+			if((!g_file_get_contents(filename, &(request->data), &(request->size), NULL)) || (request->data[0] == '\0')) {
 				request->httpstatus = 403;	/* FIXME: maybe setting request->returncode would be better */
-				ui_mainwindow_set_status_bar(_("Error: Could not open file \"%s\""), request->source);
+				ui_mainwindow_set_status_bar(_("Error: Could not open file \"%s\""), filename);
 			} else {
 				g_assert(NULL != request->data);
 				request->httpstatus = 200;
 			}
 		} else {
-			ui_mainwindow_set_status_bar(_("Error: There is no file \"%s\""), request->source);
+			ui_mainwindow_set_status_bar(_("Error: There is no file \"%s\""), filename);
 			request->httpstatus = 404;	/* FIXME: maybe setting request->returncode would be better */
 		}		
 	}
@@ -196,6 +200,7 @@ void download_request_free(struct request *request) {
 		g_free(request->lastmodified);
 		g_free(request->etag);
 		g_free(request->data);
+		g_free(request->contentType);
 		g_free(request);
 	}
 	debug_exit("update_request_free");
